@@ -19,6 +19,8 @@ package org.apache.kafka.clients.admin;
 
 /**
  * Options for {@link Admin#listClientMetricsResources()}.
+ * @deprecated Since 4.1. Use {@link ListConfigResourcesOptions} instead.
  */
+@Deprecated(since = "4.1")
 public class ListClientMetricsResourcesOptions extends AbstractOptions<ListClientMetricsResourcesOptions> {
 }
