@@ -335,7 +335,7 @@ public class MockConsumer<K, V> implements Consumer<K, V> {
      * @param maxPollRecords the max.poll.records.
      */
     public synchronized void setMaxPollRecords(long maxPollRecords) {
-        if (this.maxPollRecords < 1) {
+        if (maxPollRecords < 1) {
             throw new IllegalArgumentException("MaxPollRecords must be strictly superior to 0");
         }
         this.maxPollRecords = maxPollRecords;
@@ -575,6 +575,7 @@ public class MockConsumer<K, V> implements Consumer<K, V> {
         close(Duration.ofMillis(DEFAULT_CLOSE_TIMEOUT_MS));
     }
 
+    @Deprecated
     @Override
     public synchronized void close(Duration timeout) {
         this.closed = true;
@@ -589,6 +590,11 @@ public class MockConsumer<K, V> implements Consumer<K, V> {
         wakeup.set(true);
     }
 
+    @Override
+    public void close(CloseOptions option) {
+        this.closed = true;
+    }
+
     /**
      * Schedule a task to be executed during a poll(). One enqueued task will be executed per {@link #poll(Duration)}
      * invocation. You can use this repeatedly to mock out multiple responses to poll invocations.
