@@ -21,16 +21,17 @@ import org.apache.kafka.clients.Metadata;
 import org.apache.kafka.clients.NodeApiVersions;
 import org.apache.kafka.clients.StaleMetadataException;
 import org.apache.kafka.clients.consumer.LogTruncationException;
+import org.apache.kafka.clients.consumer.NoOffsetForPartitionException;
+import org.apache.kafka.clients.consumer.OffsetAndMetadata;
 import org.apache.kafka.clients.consumer.OffsetAndTimestamp;
 import org.apache.kafka.clients.consumer.internals.OffsetFetcherUtils.ListOffsetData;
 import org.apache.kafka.clients.consumer.internals.OffsetFetcherUtils.ListOffsetResult;
-import org.apache.kafka.clients.consumer.internals.events.BackgroundEventHandler;
-import org.apache.kafka.clients.consumer.internals.events.ErrorEvent;
 import org.apache.kafka.common.ClusterResource;
 import org.apache.kafka.common.ClusterResourceListener;
 import org.apache.kafka.common.IsolationLevel;
 import org.apache.kafka.common.Node;
 import org.apache.kafka.common.TopicPartition;
+import org.apache.kafka.common.errors.TimeoutException;
 import org.apache.kafka.common.message.ListOffsetsRequestData;
 import org.apache.kafka.common.requests.AbstractRequest;
 import org.apache.kafka.common.requests.ListOffsetsRequest;
@@ -48,14 +49,18 @@ import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
+import java.util.Objects;
 import java.util.Optional;
 import java.util.Set;
 import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.atomic.AtomicInteger;
+import java.util.concurrent.atomic.AtomicReference;
 import java.util.function.BiConsumer;
 import java.util.stream.Collectors;
 
 import static java.util.Objects.requireNonNull;
+import static org.apache.kafka.clients.consumer.internals.ConsumerUtils.maybeWrapAsKafkaException;
+import static org.apache.kafka.clients.consumer.internals.ConsumerUtils.refreshCommittedOffsets;
 import static org.apache.kafka.clients.consumer.internals.OffsetFetcherUtils.hasUsableOffsetForLeaderEpochVersion;
 import static org.apache.kafka.clients.consumer.internals.OffsetFetcherUtils.regroupFetchPositionsByLeader;
 
@@ -72,7 +77,7 @@ import static org.apache.kafka.clients.consumer.internals.OffsetFetcherUtils.reg
  * {@link ConsumerMetadata}, so this implements {@link ClusterResourceListener} to get notified
  * when the cluster metadata is updated.
  */
-public class OffsetsRequestManager implements RequestManager, ClusterResourceListener {
+public final class OffsetsRequestManager implements RequestManager, ClusterResourceListener {
 
     private final ConsumerMetadata metadata;
     private final IsolationLevel isolationLevel;
@@ -82,22 +87,38 @@ public class OffsetsRequestManager implements RequestManager, ClusterResourceLis
 
     private final Set<ListOffsetsRequestState> requestsToRetry;
     private final List<NetworkClientDelegate.UnsentRequest> requestsToSend;
-    private final long requestTimeoutMs;
+    private final int requestTimeoutMs;
     private final Time time;
     private final ApiVersions apiVersions;
     private final NetworkClientDelegate networkClientDelegate;
-    private final BackgroundEventHandler backgroundEventHandler;
+    private final CommitRequestManager commitRequestManager;
+    private final long defaultApiTimeoutMs;
+
+    /**
+     * Exception that occurred while updating positions after the triggering event had already
+     * expired. It will be propagated and cleared on the next call to update fetch positions.
+     */
+    private final AtomicReference<Throwable> cachedUpdatePositionsException = new AtomicReference<>();
+
+    /**
+     * This holds the last OffsetFetch request triggered to retrieve committed offsets to update
+     * fetch positions that hasn't completed yet. When a response is received, it's used to
+     * update the fetch positions and the pendingOffsetFetchEvent is cleared. If the update fetch
+     * positions attempt runs out of time before this OffsetFetch gets a response, it will be
+     * kept to be used on the next attempt to update fetch positions (if partitions remain the same)
+     */
+    private PendingFetchCommittedRequest pendingOffsetFetchEvent;
 
-    @SuppressWarnings("this-escape")
     public OffsetsRequestManager(final SubscriptionState subscriptionState,
                                  final ConsumerMetadata metadata,
                                  final IsolationLevel isolationLevel,
                                  final Time time,
                                  final long retryBackoffMs,
-                                 final long requestTimeoutMs,
+                                 final int requestTimeoutMs,
+                                 final long defaultApiTimeoutMs,
                                  final ApiVersions apiVersions,
                                  final NetworkClientDelegate networkClientDelegate,
-                                 final BackgroundEventHandler backgroundEventHandler,
+                                 final CommitRequestManager commitRequestManager,
                                  final LogContext logContext) {
         requireNonNull(subscriptionState);
         requireNonNull(metadata);
@@ -105,7 +126,6 @@ public class OffsetsRequestManager implements RequestManager, ClusterResourceLis
         requireNonNull(time);
         requireNonNull(apiVersions);
         requireNonNull(networkClientDelegate);
-        requireNonNull(backgroundEventHandler);
         requireNonNull(logContext);
 
         this.metadata = metadata;
@@ -116,15 +136,27 @@ public class OffsetsRequestManager implements RequestManager, ClusterResourceLis
         this.subscriptionState = subscriptionState;
         this.time = time;
         this.requestTimeoutMs = requestTimeoutMs;
+        this.defaultApiTimeoutMs = defaultApiTimeoutMs;
         this.apiVersions = apiVersions;
         this.networkClientDelegate = networkClientDelegate;
-        this.backgroundEventHandler = backgroundEventHandler;
         this.offsetFetcherUtils = new OffsetFetcherUtils(logContext, metadata, subscriptionState,
                 time, retryBackoffMs, apiVersions);
         // Register the cluster metadata update callback. Note this only relies on the
         // requestsToRetry initialized above, and won't be invoked until all managers are
         // initialized and the network thread started.
         this.metadata.addClusterUpdateListener(this);
+        this.commitRequestManager = commitRequestManager;
+    }
+
+    private static class PendingFetchCommittedRequest {
+        final Set<TopicPartition> requestedPartitions;
+        final CompletableFuture<Map<TopicPartition, OffsetAndMetadata>> result;
+
+        private PendingFetchCommittedRequest(final Set<TopicPartition> requestedPartitions,
+                                             final CompletableFuture<Map<TopicPartition, OffsetAndMetadata>> result) {
+            this.requestedPartitions = Objects.requireNonNull(requestedPartitions);
+            this.result = Objects.requireNonNull(result);
+        }
     }
 
     /**
@@ -182,32 +214,278 @@ public class OffsetsRequestManager implements RequestManager, ClusterResourceLis
                         result.fetchedOffsets));
     }
 
+    /**
+     * Update fetch positions for assigned partitions that do not have a position. This will:
+     * <ul>
+     *     <li>check if all assigned partitions already have fetch positions and return right away if that's the case</li>
+     *     <li>trigger an async request to validate positions (detect log truncation)</li>
+     *     <li>fetch committed offsets if enabled, and use the response to update the positions</li>
+     *     <li>fetch partition offsets for partitions that may still require a position, and use the response to
+     *     update the positions</li>
+     * </ul>
+     *
+     * @param deadlineMs Time in milliseconds when the triggering application event expires. Any error received after
+     *                   this will be saved, and used to complete the result exceptionally on the next call to this
+     *                   function.
+     * @return Future that will complete with a boolean indicating if all assigned partitions have positions (based
+     * on {@link SubscriptionState#hasAllFetchPositions()}). It will complete immediately, with true, if all positions
+     * are already available. If some positions are missing, the future will complete once the offsets are retrieved and positions are updated.
+     */
+    public CompletableFuture<Boolean> updateFetchPositions(long deadlineMs) {
+        CompletableFuture<Boolean> result = new CompletableFuture<>();
+
+        try {
+            if (maybeCompleteWithPreviousException(result)) {
+                return result;
+            }
+
+            validatePositionsIfNeeded();
+
+            if (subscriptionState.hasAllFetchPositions()) {
+                // All positions are already available
+                result.complete(true);
+                return result;
+            }
+
+            // Some positions are missing, so trigger requests to fetch offsets and update them.
+            updatePositionsWithOffsets(deadlineMs).whenComplete((__, error) -> {
+                if (error != null) {
+                    result.completeExceptionally(error);
+                } else {
+                    result.complete(subscriptionState.hasAllFetchPositions());
+                }
+            });
+
+        } catch (Exception e) {
+            result.completeExceptionally(maybeWrapAsKafkaException(e));
+        }
+        return result;
+    }
+
+    private boolean maybeCompleteWithPreviousException(CompletableFuture<Boolean> result) {
+        Throwable cachedException = cachedUpdatePositionsException.getAndSet(null);
+        if (cachedException != null) {
+            result.completeExceptionally(cachedException);
+            return true;
+        }
+        return false;
+    }
+
+    /**
+     * Generate requests to fetch offsets and update positions once a response is received. This will first attempt
+     * to use the committed offsets if available. If no committed offsets available, it will use the partition
+     * offsets retrieved from the leader.
+     */
+    private CompletableFuture<Void> updatePositionsWithOffsets(long deadlineMs) {
+        CompletableFuture<Void> result = new CompletableFuture<>();
+
+        cacheExceptionIfEventExpired(result, deadlineMs);
+
+        CompletableFuture<Void> updatePositions;
+        final Set<TopicPartition> initializingPartitions = subscriptionState.initializingPartitions();
+        if (commitRequestManager != null) {
+            CompletableFuture<Void> refreshWithCommittedOffsets = initWithCommittedOffsetsIfNeeded(initializingPartitions, deadlineMs);
+
+            // Reset positions for all partitions that may still require it (or that are awaiting reset)
+            updatePositions = refreshWithCommittedOffsets.thenCompose(__ -> initWithPartitionOffsetsIfNeeded(initializingPartitions));
+
+        } else {
+            updatePositions = initWithPartitionOffsetsIfNeeded(initializingPartitions);
+        }
+
+        updatePositions.whenComplete((__, resetError) -> {
+            if (resetError == null) {
+                result.complete(null);
+            } else {
+                result.completeExceptionally(resetError);
+            }
+        });
+
+        return result;
+    }
+
+    /**
+     * Save exception that may occur while updating fetch positions. Note that since the update fetch positions
+     * is triggered asynchronously, errors may be found when the triggering UpdateFetchPositionsEvent has already
+     * expired. In that case, the exception is saved in memory, to be thrown when processing the following
+     * UpdateFetchPositionsEvent.
+     *
+     * @param result     Update fetch positions future to get the exception from (if any)
+     * @param deadlineMs Deadline of the triggering application event, used to identify if the event has already
+     *                   expired when the error in the result future occurs.
+     */
+    private void cacheExceptionIfEventExpired(CompletableFuture<Void> result, long deadlineMs) {
+        result.whenComplete((__, error) -> {
+            boolean updatePositionsExpired = time.milliseconds() >= deadlineMs;
+            if (error != null && updatePositionsExpired) {
+                cachedUpdatePositionsException.set(error);
+            }
+        });
+    }
+
+    /**
+     * If there are partitions still needing a position and a reset policy is defined, request reset using the default policy.
+     *
+     * @param initializingPartitions Set of partitions that should be initialized. This won't reset positions for
+     *                               partitions that may have been added to the subscription state, but that are not
+     *                               included in this set.
+     * @return Future that will complete when the reset operation completes retrieving the offsets and setting
+     * positions in the subscription state using them.
+     * @throws NoOffsetForPartitionException If no reset strategy is configured.
+     */
+    private CompletableFuture<Void> initWithPartitionOffsetsIfNeeded(Set<TopicPartition> initializingPartitions) {
+        CompletableFuture<Void> result = new CompletableFuture<>();
+        try {
+            // Mark partitions that need reset, using the configured reset strategy. If no
+            // strategy is defined, this will raise a NoOffsetForPartitionException exception.
+            subscriptionState.resetInitializingPositions(initializingPartitions::contains);
+        } catch (Exception e) {
+            result.completeExceptionally(e);
+            return result;
+        }
+
+        // For partitions awaiting reset, generate a ListOffset request to retrieve the partition
+        // offsets according to the strategy (ex. earliest, latest), and update the positions.
+        return resetPositionsIfNeeded();
+    }
+
+    /**
+     * Fetch the committed offsets for partitions that require initialization. This will trigger an OffsetFetch
+     * request and update positions in the subscription state once a response is received.
+     *
+     * @param initializingPartitions Set of partitions to update with a position. This same set will be kept
+     *                               throughout the whole process (considered when fetching committed offsets, and
+     *                               when resetting positions for partitions that may not have committed offsets).
+     * @param deadlineMs             Deadline of the application event that triggered this operation. Used to
+     *                               determine how much time to allow for the reused offset fetch to complete.
+     * @throws TimeoutException If offsets could not be retrieved within the timeout
+     */
+    private CompletableFuture<Void> initWithCommittedOffsetsIfNeeded(Set<TopicPartition> initializingPartitions,
+                                                                     long deadlineMs) {
+        if (initializingPartitions.isEmpty()) {
+            return CompletableFuture.completedFuture(null);
+        }
+
+        log.debug("Refreshing committed offsets for partitions {}", initializingPartitions);
+        CompletableFuture<Void> result = new CompletableFuture<>();
+
+        // The shorter the timeout provided to poll(), the more likely the offsets fetch will time out. To handle
+        // this case, on the first attempt to fetch the committed offsets, a FetchCommittedOffsetsEvent is created
+        // (with potentially a longer timeout) and stored. The event is used for the first attempt, but in the
+        // case it times out, subsequent attempts will also use the event in order to wait for the results.
+        if (!canReusePendingOffsetFetchEvent(initializingPartitions)) {
+            // Generate a new OffsetFetch request and update positions when a response is received
+            final long fetchCommittedDeadlineMs = Math.max(deadlineMs, time.milliseconds() + defaultApiTimeoutMs);
+            CompletableFuture<Map<TopicPartition, OffsetAndMetadata>> fetchOffsets =
+                    commitRequestManager.fetchOffsets(initializingPartitions, fetchCommittedDeadlineMs);
+            CompletableFuture<Map<TopicPartition, OffsetAndMetadata>> fetchOffsetsAndRefresh =
+                    fetchOffsets.whenComplete((offsets, error) -> {
+                        pendingOffsetFetchEvent = null;
+                        // Update positions with the retrieved offsets
+                        refreshOffsets(offsets, error, result);
+                    });
+            pendingOffsetFetchEvent = new PendingFetchCommittedRequest(initializingPartitions, fetchOffsetsAndRefresh);
+        } else {
+            // Reuse pending OffsetFetch request that will complete when positions are refreshed with the committed offsets retrieved
+            pendingOffsetFetchEvent.result.whenComplete((__, error) -> {
+                if (error == null) {
+                    result.complete(null);
+                } else {
+                    result.completeExceptionally(error);
+                }
+            });
+        }
+
+        return result;
+    }
+
+    /**
+     * Use the given committed offsets to update positions for partitions that still require it.
+     *
+     * @param offsets Committed offsets to use to update positions for initializing partitions.
+     * @param error   Error received in response to the OffsetFetch request. Will be null if the request was successful.
+     * @param result  Future to complete once all positions have been updated with the given committed offsets
+     */
+    private void refreshOffsets(final Map<TopicPartition, OffsetAndMetadata> offsets,
+                                final Throwable error,
+                                final CompletableFuture<Void> result) {
+        if (error == null) {
+
+            // Ensure we only set positions for the partitions that still require one (ex. some partitions may have
+            // been assigned a position manually)
+            Map<TopicPartition, OffsetAndMetadata> offsetsToApply = offsetsForInitializingPartitions(offsets);
+
+            refreshCommittedOffsets(offsetsToApply, metadata, subscriptionState);
+
+            result.complete(null);
+
+        } else {
+            log.error("Error fetching committed offsets to update positions", error);
+            result.completeExceptionally(error);
+        }
+    }
+
+    /**
+     * Get the offsets, from the given collection, that belong to partitions that still require a position (partitions
+     * that are initializing). This is expected to be used to filter out offsets that were retrieved for partitions
+     * that do not need a position anymore.
+     *
+     * @param offsets Offsets per partition
+     * @return Subset of the offsets associated to partitions that are still initializing
+     */
+    private Map<TopicPartition, OffsetAndMetadata> offsetsForInitializingPartitions(Map<TopicPartition, OffsetAndMetadata> offsets) {
+        Set<TopicPartition> currentlyInitializingPartitions = subscriptionState.initializingPartitions();
+        Map<TopicPartition, OffsetAndMetadata> result = new HashMap<>();
+        offsets.forEach((key, value) -> {
+            if (currentlyInitializingPartitions.contains(key)) {
+                result.put(key, value);
+            }
+        });
+        return result;
+    }
+
+    /**
+     * This determines if the {@link #pendingOffsetFetchEvent pending offset fetch event} can be reused. Reuse
+     * is only possible if all the following conditions are true:
+     *
+     * <ul>
+     *     <li>A pending offset fetch event exists</li>
+     *     <li>The partition set of the pending offset fetch event is the same as the given partitions</li>
+     * </ul>
+     */
+    private boolean canReusePendingOffsetFetchEvent(Set<TopicPartition> partitions) {
+        if (pendingOffsetFetchEvent == null) {
+            return false;
+        }
+
+        return pendingOffsetFetchEvent.requestedPartitions.equals(partitions);
+    }
+
     /**
      * Reset offsets for all assigned partitions that require it. Offsets will be reset
      * with timestamps according to the reset strategy defined for each partition. This will
      * generate ListOffsets requests for the partitions and timestamps, and enqueue them to be sent
      * on the next call to {@link #poll(long)}.
-     *
      * <p/>
-     *
      * When a response is received, positions are updated in-memory, on the subscription state. If
      * an error is received in the response, it will be saved to be thrown on the next call to
      * this function (ex. {@link org.apache.kafka.common.errors.TopicAuthorizationException})
      */
-    public CompletableFuture<Void> resetPositionsIfNeeded() {
-        Map<TopicPartition, Long> offsetResetTimestamps;
+    CompletableFuture<Void> resetPositionsIfNeeded() {
+        Map<TopicPartition, AutoOffsetResetStrategy> partitionAutoOffsetResetStrategyMap;
 
         try {
-            offsetResetTimestamps = offsetFetcherUtils.getOffsetResetTimestamp();
+            partitionAutoOffsetResetStrategyMap = offsetFetcherUtils.getOffsetResetStrategyForPartitions();
         } catch (Exception e) {
-            backgroundEventHandler.add(new ErrorEvent(e));
-            return CompletableFuture.completedFuture(null);
+            CompletableFuture<Void> result = new CompletableFuture<>();
+            result.completeExceptionally(e);
+            return result;
         }
 
-        if (offsetResetTimestamps.isEmpty())
+        if (partitionAutoOffsetResetStrategyMap.isEmpty())
             return CompletableFuture.completedFuture(null);
 
-        return sendListOffsetsRequestsAndResetPositions(offsetResetTimestamps);
+        return sendListOffsetsRequestsAndResetPositions(partitionAutoOffsetResetStrategyMap);
     }
 
     /**
@@ -218,18 +496,17 @@ public class OffsetsRequestManager implements RequestManager, ClusterResourceLis
      *
      * <p/>
      *
-     * When a response is received, positions are validated and, if a log truncation is
-     * detected, a {@link LogTruncationException} will be saved in memory, to be thrown on the
+     * When a response is received, positions are validated and, if a log truncation is detected, a
+     * {@link LogTruncationException} will be saved in memory in cachedUpdatePositionsException, to be thrown on the
      * next call to this function.
      */
-    public CompletableFuture<Void> validatePositionsIfNeeded() {
-        Map<TopicPartition, SubscriptionState.FetchPosition> partitionsToValidate =
-                offsetFetcherUtils.getPartitionsToValidate();
+    void validatePositionsIfNeeded() {
+        Map<TopicPartition, SubscriptionState.FetchPosition> partitionsToValidate = offsetFetcherUtils.getPartitionsToValidate();
         if (partitionsToValidate.isEmpty()) {
-            return CompletableFuture.completedFuture(null);
+            return;
         }
 
-        return sendOffsetsForLeaderEpochRequestsAndValidatePositions(partitionsToValidate);
+        sendOffsetsForLeaderEpochRequestsAndValidatePositions(partitionsToValidate);
     }
 
     /**
@@ -301,6 +578,7 @@ public class OffsetsRequestManager implements RequestManager, ClusterResourceLis
                     listOffsetsRequestState.globalResult.complete(listOffsetResult);
                 } else {
                     requestsToRetry.add(listOffsetsRequestState);
+                    metadata.requestUpdate(false);
                 }
             } else {
                 log.debug("ListOffsets request failed with error", error);
@@ -338,7 +616,8 @@ public class OffsetsRequestManager implements RequestManager, ClusterResourceLis
             List<NetworkClientDelegate.UnsentRequest> unsentRequests) {
         ListOffsetsRequest.Builder builder = ListOffsetsRequest.Builder
                 .forConsumer(requireTimestamps, isolationLevel)
-                .setTargetTimes(ListOffsetsRequest.toListOffsetsTopics(targetTimes));
+                .setTargetTimes(ListOffsetsRequest.toListOffsetsTopics(targetTimes))
+                .setTimeoutMs(requestTimeoutMs);
 
         log.debug("Creating ListOffset request {} for broker {} to reset positions", builder,
                 node);
@@ -374,12 +653,14 @@ public class OffsetsRequestManager implements RequestManager, ClusterResourceLis
      * partitions. Use the retrieved offsets to reset positions in the subscription state.
      * This also adds the request to the list of unsentRequests.
      *
-     * @param timestampsToSearch the mapping between partitions and target time
+     * @param partitionAutoOffsetResetStrategyMap the mapping between partitions and AutoOffsetResetStrategy
      * @return A {@link CompletableFuture} which completes when the requests are
      * complete.
      */
     private CompletableFuture<Void> sendListOffsetsRequestsAndResetPositions(
-            final Map<TopicPartition, Long> timestampsToSearch) {
+            final Map<TopicPartition, AutoOffsetResetStrategy> partitionAutoOffsetResetStrategyMap) {
+        Map<TopicPartition, Long> timestampsToSearch = partitionAutoOffsetResetStrategyMap.entrySet().stream()
+                .collect(Collectors.toMap(Map.Entry::getKey, e -> e.getValue().timestamp().get()));
         Map<Node, Map<TopicPartition, ListOffsetsRequestData.ListOffsetsPartition>> timestampsToSearchByNode =
                 groupListOffsetRequests(timestampsToSearch, Optional.empty());
 
@@ -399,8 +680,8 @@ public class OffsetsRequestManager implements RequestManager, ClusterResourceLis
 
             partialResult.whenComplete((result, error) -> {
                 if (error == null) {
-                    offsetFetcherUtils.onSuccessfulResponseForResettingPositions(resetTimestamps,
-                            result);
+                    offsetFetcherUtils.onSuccessfulResponseForResettingPositions(result,
+                            partitionAutoOffsetResetStrategyMap);
                 } else {
                     RuntimeException e;
                     if (error instanceof RuntimeException) {
@@ -435,19 +716,15 @@ public class OffsetsRequestManager implements RequestManager, ClusterResourceLis
      * This also adds the request to the list of unsentRequests.
      *
      * @param partitionsToValidate a map of topic-partition positions to validate
-     * @return A {@link CompletableFuture} which completes when the requests are
-     * complete.
 
      */
-    private CompletableFuture<Void> sendOffsetsForLeaderEpochRequestsAndValidatePositions(
+    private void sendOffsetsForLeaderEpochRequestsAndValidatePositions(
             Map<TopicPartition, SubscriptionState.FetchPosition> partitionsToValidate) {
 
         final Map<Node, Map<TopicPartition, SubscriptionState.FetchPosition>> regrouped =
                 regroupFetchPositionsByLeader(partitionsToValidate);
 
         long nextResetTimeMs = time.milliseconds() + requestTimeoutMs;
-        final AtomicInteger expectedResponses = new AtomicInteger(0);
-        final CompletableFuture<Void> globalResult = new CompletableFuture<>();
         final List<NetworkClientDelegate.UnsentRequest> unsentRequests = new ArrayList<>();
         regrouped.forEach((node, fetchPositions) -> {
 
@@ -491,20 +768,10 @@ public class OffsetsRequestManager implements RequestManager, ClusterResourceLis
                     }
                     offsetFetcherUtils.onFailedResponseForValidatingPositions(fetchPositions, e);
                 }
-                if (expectedResponses.decrementAndGet() == 0) {
-                    globalResult.complete(null);
-                }
             });
         });
 
-        if (unsentRequests.isEmpty()) {
-            globalResult.complete(null);
-        } else {
-            expectedResponses.set(unsentRequests.size());
-            requestsToSend.addAll(unsentRequests);
-        }
-
-        return globalResult;
+        requestsToSend.addAll(unsentRequests);
     }
 
     /**
@@ -630,7 +897,7 @@ public class OffsetsRequestManager implements RequestManager, ClusterResourceLis
             Long offset = entry.getValue();
             Metadata.LeaderAndEpoch leaderAndEpoch = metadata.currentLeader(tp);
 
-            if (!leaderAndEpoch.leader.isPresent()) {
+            if (leaderAndEpoch.leader.isEmpty()) {
                 log.debug("Leader for partition {} is unknown for fetching offset {}", tp, offset);
                 metadata.requestUpdate(true);
                 listOffsetsRequestState.ifPresent(offsetsRequestState -> offsetsRequestState.remainingToSearch.put(tp, offset));
