@@ -30,7 +30,6 @@ import org.apache.kafka.common.utils.AbstractIterator;
 import org.apache.kafka.common.utils.BufferSupplier;
 import org.apache.kafka.common.utils.ByteBufferOutputStream;
 import org.apache.kafka.common.utils.CloseableIterator;
-import org.apache.kafka.common.utils.Time;
 import org.apache.kafka.common.utils.Utils;
 
 import java.io.IOException;
@@ -107,11 +106,6 @@ public class MemoryRecords extends AbstractRecords {
         return bytes;
     }
 
-    @Override
-    public ConvertedRecords<MemoryRecords> downConvert(byte toMagic, long firstOffset, Time time) {
-        return RecordsUtil.downConvert(batches(), toMagic, firstOffset, time);
-    }
-
     @Override
     public AbstractIterator<MutableRecordBatch> batchIterator() {
         return new RecordBatchIterator<>(new ByteBufferLogInputStream(buffer.duplicate(), Integer.MAX_VALUE));
@@ -306,6 +300,31 @@ public class MemoryRecords extends AbstractRecords {
         return buffer.duplicate();
     }
 
+    @Override
+    public MemoryRecords slice(int position, int size) {
+        if (position < 0)
+            throw new IllegalArgumentException("Invalid position: " + position + " in read from " + this);
+        if (position > buffer.limit())
+            throw new IllegalArgumentException("Slice from position " + position + " exceeds end position of " + this);
+        if (size < 0)
+            throw new IllegalArgumentException("Invalid size: " + size + " in read from " + this);
+
+        int availableBytes = Math.min(size, buffer.limit() - position);
+        // As of now, clients module support Java11 hence can't use ByteBuffer::slice(position, size) method.
+        // So we need to create a duplicate buffer and set the position and limit. Duplicate buffer
+        // is backed by original bytes hence not the content but only the relative position and limit
+        // are changed in the duplicate buffer. Once the position and limit are set, we can call the
+        // slice method to get the sliced buffer, which is a backed by the original buffer with the
+        // position reset to 0 and limit set to the size of the slice.
+        ByteBuffer slicedBuffer = buffer.duplicate();
+        slicedBuffer.position(position);
+        slicedBuffer.limit(position + availableBytes);
+        // Reset the position to 0 so that the sliced view has a relative position.
+        slicedBuffer = slicedBuffer.slice();
+
+        return readableRecords(slicedBuffer);
+    }
+
     @Override
     public Iterable<MutableRecordBatch> batches() {
         return batches;
@@ -684,8 +703,7 @@ public class MemoryRecords extends AbstractRecords {
     public static MemoryRecords withEndTransactionMarker(long initialOffset, long timestamp, int partitionLeaderEpoch,
                                                          long producerId, short producerEpoch,
                                                          EndTransactionMarker marker) {
-        int endTxnMarkerBatchSize = DefaultRecordBatch.RECORD_BATCH_OVERHEAD +
-                EndTransactionMarker.CURRENT_END_TXN_SCHEMA_RECORD_SIZE;
+        int endTxnMarkerBatchSize = DefaultRecordBatch.RECORD_BATCH_OVERHEAD + marker.endTxnMarkerValueSize();
         ByteBuffer buffer = ByteBuffer.allocate(endTxnMarkerBatchSize);
         writeEndTransactionalMarker(buffer, initialOffset, timestamp, partitionLeaderEpoch, producerId,
                 producerEpoch, marker);
