@@ -18,14 +18,16 @@ package org.apache.kafka.common.requests;
 
 import org.apache.kafka.common.network.Send;
 import org.apache.kafka.common.protocol.ApiKeys;
+import org.apache.kafka.common.protocol.ByteBufferAccessor;
 import org.apache.kafka.common.protocol.Errors;
 import org.apache.kafka.common.protocol.MessageUtil;
+import org.apache.kafka.common.protocol.Readable;
 import org.apache.kafka.common.protocol.SendBuilder;
 
 import java.nio.ByteBuffer;
 import java.util.Collection;
 import java.util.Collections;
-import java.util.HashMap;
+import java.util.EnumMap;
 import java.util.Map;
 import java.util.stream.Collectors;
 import java.util.stream.Stream;
@@ -51,8 +53,8 @@ public abstract class AbstractResponse implements AbstractRequestResponse {
     }
 
     // Visible for testing
-    final ByteBuffer serialize(short version) {
-        return MessageUtil.toByteBuffer(data(), version);
+    final ByteBufferAccessor serialize(short version) {
+        return MessageUtil.toByteBufferAccessor(data(), version);
     }
 
     /**
@@ -71,14 +73,14 @@ public abstract class AbstractResponse implements AbstractRequestResponse {
     }
 
     protected static Map<Errors, Integer> errorCounts(Collection<Errors> errors) {
-        Map<Errors, Integer> errorCounts = new HashMap<>();
+        Map<Errors, Integer> errorCounts = new EnumMap<>(Errors.class);
         for (Errors error : errors)
             updateErrorCounts(errorCounts, error);
         return errorCounts;
     }
 
     protected static Map<Errors, Integer> apiErrorCounts(Map<?, ApiError> errors) {
-        Map<Errors, Integer> errorCounts = new HashMap<>();
+        Map<Errors, Integer> errorCounts = new EnumMap<>(Errors.class);
         for (ApiError apiError : errors.values())
             updateErrorCounts(errorCounts, apiError.error());
         return errorCounts;
@@ -106,179 +108,189 @@ public abstract class AbstractResponse implements AbstractRequestResponse {
                 requestHeader.correlationId(), responseHeader.correlationId());
         }
 
-        return AbstractResponse.parseResponse(apiKey, buffer, apiVersion);
+        return AbstractResponse.parseResponse(apiKey, new ByteBufferAccessor(buffer), apiVersion);
     }
 
-    public static AbstractResponse parseResponse(ApiKeys apiKey, ByteBuffer responseBuffer, short version) {
+    public static AbstractResponse parseResponse(ApiKeys apiKey, Readable readable, short version) {
         switch (apiKey) {
             case PRODUCE:
-                return ProduceResponse.parse(responseBuffer, version);
+                return ProduceResponse.parse(readable, version);
             case FETCH:
-                return FetchResponse.parse(responseBuffer, version);
+                return FetchResponse.parse(readable, version);
             case LIST_OFFSETS:
-                return ListOffsetsResponse.parse(responseBuffer, version);
+                return ListOffsetsResponse.parse(readable, version);
             case METADATA:
-                return MetadataResponse.parse(responseBuffer, version);
+                return MetadataResponse.parse(readable, version);
             case OFFSET_COMMIT:
-                return OffsetCommitResponse.parse(responseBuffer, version);
+                return OffsetCommitResponse.parse(readable, version);
             case OFFSET_FETCH:
-                return OffsetFetchResponse.parse(responseBuffer, version);
+                return OffsetFetchResponse.parse(readable, version);
             case FIND_COORDINATOR:
-                return FindCoordinatorResponse.parse(responseBuffer, version);
+                return FindCoordinatorResponse.parse(readable, version);
             case JOIN_GROUP:
-                return JoinGroupResponse.parse(responseBuffer, version);
+                return JoinGroupResponse.parse(readable, version);
             case HEARTBEAT:
-                return HeartbeatResponse.parse(responseBuffer, version);
+                return HeartbeatResponse.parse(readable, version);
             case LEAVE_GROUP:
-                return LeaveGroupResponse.parse(responseBuffer, version);
+                return LeaveGroupResponse.parse(readable, version);
             case SYNC_GROUP:
-                return SyncGroupResponse.parse(responseBuffer, version);
+                return SyncGroupResponse.parse(readable, version);
             case DESCRIBE_GROUPS:
-                return DescribeGroupsResponse.parse(responseBuffer, version);
+                return DescribeGroupsResponse.parse(readable, version);
             case LIST_GROUPS:
-                return ListGroupsResponse.parse(responseBuffer, version);
+                return ListGroupsResponse.parse(readable, version);
             case SASL_HANDSHAKE:
-                return SaslHandshakeResponse.parse(responseBuffer, version);
+                return SaslHandshakeResponse.parse(readable, version);
             case API_VERSIONS:
-                return ApiVersionsResponse.parse(responseBuffer, version);
+                return ApiVersionsResponse.parse(readable, version);
             case CREATE_TOPICS:
-                return CreateTopicsResponse.parse(responseBuffer, version);
+                return CreateTopicsResponse.parse(readable, version);
             case DELETE_TOPICS:
-                return DeleteTopicsResponse.parse(responseBuffer, version);
+                return DeleteTopicsResponse.parse(readable, version);
             case DELETE_RECORDS:
-                return DeleteRecordsResponse.parse(responseBuffer, version);
+                return DeleteRecordsResponse.parse(readable, version);
             case INIT_PRODUCER_ID:
-                return InitProducerIdResponse.parse(responseBuffer, version);
+                return InitProducerIdResponse.parse(readable, version);
             case OFFSET_FOR_LEADER_EPOCH:
-                return OffsetsForLeaderEpochResponse.parse(responseBuffer, version);
+                return OffsetsForLeaderEpochResponse.parse(readable, version);
             case ADD_PARTITIONS_TO_TXN:
-                return AddPartitionsToTxnResponse.parse(responseBuffer, version);
+                return AddPartitionsToTxnResponse.parse(readable, version);
             case ADD_OFFSETS_TO_TXN:
-                return AddOffsetsToTxnResponse.parse(responseBuffer, version);
+                return AddOffsetsToTxnResponse.parse(readable, version);
             case END_TXN:
-                return EndTxnResponse.parse(responseBuffer, version);
+                return EndTxnResponse.parse(readable, version);
             case WRITE_TXN_MARKERS:
-                return WriteTxnMarkersResponse.parse(responseBuffer, version);
+                return WriteTxnMarkersResponse.parse(readable, version);
             case TXN_OFFSET_COMMIT:
-                return TxnOffsetCommitResponse.parse(responseBuffer, version);
+                return TxnOffsetCommitResponse.parse(readable, version);
             case DESCRIBE_ACLS:
-                return DescribeAclsResponse.parse(responseBuffer, version);
+                return DescribeAclsResponse.parse(readable, version);
             case CREATE_ACLS:
-                return CreateAclsResponse.parse(responseBuffer, version);
+                return CreateAclsResponse.parse(readable, version);
             case DELETE_ACLS:
-                return DeleteAclsResponse.parse(responseBuffer, version);
+                return DeleteAclsResponse.parse(readable, version);
             case DESCRIBE_CONFIGS:
-                return DescribeConfigsResponse.parse(responseBuffer, version);
+                return DescribeConfigsResponse.parse(readable, version);
             case ALTER_CONFIGS:
-                return AlterConfigsResponse.parse(responseBuffer, version);
+                return AlterConfigsResponse.parse(readable, version);
             case ALTER_REPLICA_LOG_DIRS:
-                return AlterReplicaLogDirsResponse.parse(responseBuffer, version);
+                return AlterReplicaLogDirsResponse.parse(readable, version);
             case DESCRIBE_LOG_DIRS:
-                return DescribeLogDirsResponse.parse(responseBuffer, version);
+                return DescribeLogDirsResponse.parse(readable, version);
             case SASL_AUTHENTICATE:
-                return SaslAuthenticateResponse.parse(responseBuffer, version);
+                return SaslAuthenticateResponse.parse(readable, version);
             case CREATE_PARTITIONS:
-                return CreatePartitionsResponse.parse(responseBuffer, version);
+                return CreatePartitionsResponse.parse(readable, version);
             case CREATE_DELEGATION_TOKEN:
-                return CreateDelegationTokenResponse.parse(responseBuffer, version);
+                return CreateDelegationTokenResponse.parse(readable, version);
             case RENEW_DELEGATION_TOKEN:
-                return RenewDelegationTokenResponse.parse(responseBuffer, version);
+                return RenewDelegationTokenResponse.parse(readable, version);
             case EXPIRE_DELEGATION_TOKEN:
-                return ExpireDelegationTokenResponse.parse(responseBuffer, version);
+                return ExpireDelegationTokenResponse.parse(readable, version);
             case DESCRIBE_DELEGATION_TOKEN:
-                return DescribeDelegationTokenResponse.parse(responseBuffer, version);
+                return DescribeDelegationTokenResponse.parse(readable, version);
             case DELETE_GROUPS:
-                return DeleteGroupsResponse.parse(responseBuffer, version);
+                return DeleteGroupsResponse.parse(readable, version);
             case ELECT_LEADERS:
-                return ElectLeadersResponse.parse(responseBuffer, version);
+                return ElectLeadersResponse.parse(readable, version);
             case INCREMENTAL_ALTER_CONFIGS:
-                return IncrementalAlterConfigsResponse.parse(responseBuffer, version);
+                return IncrementalAlterConfigsResponse.parse(readable, version);
             case ALTER_PARTITION_REASSIGNMENTS:
-                return AlterPartitionReassignmentsResponse.parse(responseBuffer, version);
+                return AlterPartitionReassignmentsResponse.parse(readable, version);
             case LIST_PARTITION_REASSIGNMENTS:
-                return ListPartitionReassignmentsResponse.parse(responseBuffer, version);
+                return ListPartitionReassignmentsResponse.parse(readable, version);
             case OFFSET_DELETE:
-                return OffsetDeleteResponse.parse(responseBuffer, version);
+                return OffsetDeleteResponse.parse(readable, version);
             case DESCRIBE_CLIENT_QUOTAS:
-                return DescribeClientQuotasResponse.parse(responseBuffer, version);
+                return DescribeClientQuotasResponse.parse(readable, version);
             case ALTER_CLIENT_QUOTAS:
-                return AlterClientQuotasResponse.parse(responseBuffer, version);
+                return AlterClientQuotasResponse.parse(readable, version);
             case DESCRIBE_USER_SCRAM_CREDENTIALS:
-                return DescribeUserScramCredentialsResponse.parse(responseBuffer, version);
+                return DescribeUserScramCredentialsResponse.parse(readable, version);
             case ALTER_USER_SCRAM_CREDENTIALS:
-                return AlterUserScramCredentialsResponse.parse(responseBuffer, version);
+                return AlterUserScramCredentialsResponse.parse(readable, version);
             case VOTE:
-                return VoteResponse.parse(responseBuffer, version);
+                return VoteResponse.parse(readable, version);
             case BEGIN_QUORUM_EPOCH:
-                return BeginQuorumEpochResponse.parse(responseBuffer, version);
+                return BeginQuorumEpochResponse.parse(readable, version);
             case END_QUORUM_EPOCH:
-                return EndQuorumEpochResponse.parse(responseBuffer, version);
+                return EndQuorumEpochResponse.parse(readable, version);
             case DESCRIBE_QUORUM:
-                return DescribeQuorumResponse.parse(responseBuffer, version);
+                return DescribeQuorumResponse.parse(readable, version);
             case ALTER_PARTITION:
-                return AlterPartitionResponse.parse(responseBuffer, version);
+                return AlterPartitionResponse.parse(readable, version);
             case UPDATE_FEATURES:
-                return UpdateFeaturesResponse.parse(responseBuffer, version);
+                return UpdateFeaturesResponse.parse(readable, version);
             case ENVELOPE:
-                return EnvelopeResponse.parse(responseBuffer, version);
+                return EnvelopeResponse.parse(readable, version);
             case FETCH_SNAPSHOT:
-                return FetchSnapshotResponse.parse(responseBuffer, version);
+                return FetchSnapshotResponse.parse(readable, version);
             case DESCRIBE_CLUSTER:
-                return DescribeClusterResponse.parse(responseBuffer, version);
+                return DescribeClusterResponse.parse(readable, version);
             case DESCRIBE_PRODUCERS:
-                return DescribeProducersResponse.parse(responseBuffer, version);
+                return DescribeProducersResponse.parse(readable, version);
             case BROKER_REGISTRATION:
-                return BrokerRegistrationResponse.parse(responseBuffer, version);
+                return BrokerRegistrationResponse.parse(readable, version);
             case BROKER_HEARTBEAT:
-                return BrokerHeartbeatResponse.parse(responseBuffer, version);
+                return BrokerHeartbeatResponse.parse(readable, version);
             case UNREGISTER_BROKER:
-                return UnregisterBrokerResponse.parse(responseBuffer, version);
+                return UnregisterBrokerResponse.parse(readable, version);
             case DESCRIBE_TRANSACTIONS:
-                return DescribeTransactionsResponse.parse(responseBuffer, version);
+                return DescribeTransactionsResponse.parse(readable, version);
             case LIST_TRANSACTIONS:
-                return ListTransactionsResponse.parse(responseBuffer, version);
+                return ListTransactionsResponse.parse(readable, version);
             case ALLOCATE_PRODUCER_IDS:
-                return AllocateProducerIdsResponse.parse(responseBuffer, version);
+                return AllocateProducerIdsResponse.parse(readable, version);
             case CONSUMER_GROUP_HEARTBEAT:
-                return ConsumerGroupHeartbeatResponse.parse(responseBuffer, version);
+                return ConsumerGroupHeartbeatResponse.parse(readable, version);
             case CONSUMER_GROUP_DESCRIBE:
-                return ConsumerGroupDescribeResponse.parse(responseBuffer, version);
+                return ConsumerGroupDescribeResponse.parse(readable, version);
             case CONTROLLER_REGISTRATION:
-                return ControllerRegistrationResponse.parse(responseBuffer, version);
+                return ControllerRegistrationResponse.parse(readable, version);
             case GET_TELEMETRY_SUBSCRIPTIONS:
-                return GetTelemetrySubscriptionsResponse.parse(responseBuffer, version);
+                return GetTelemetrySubscriptionsResponse.parse(readable, version);
             case PUSH_TELEMETRY:
-                return PushTelemetryResponse.parse(responseBuffer, version);
+                return PushTelemetryResponse.parse(readable, version);
             case ASSIGN_REPLICAS_TO_DIRS:
-                return AssignReplicasToDirsResponse.parse(responseBuffer, version);
-            case LIST_CLIENT_METRICS_RESOURCES:
-                return ListClientMetricsResourcesResponse.parse(responseBuffer, version);
+                return AssignReplicasToDirsResponse.parse(readable, version);
+            case LIST_CONFIG_RESOURCES:
+                return ListConfigResourcesResponse.parse(readable, version);
             case DESCRIBE_TOPIC_PARTITIONS:
-                return DescribeTopicPartitionsResponse.parse(responseBuffer, version);
+                return DescribeTopicPartitionsResponse.parse(readable, version);
             case SHARE_GROUP_HEARTBEAT:
-                return ShareGroupHeartbeatResponse.parse(responseBuffer, version);
+                return ShareGroupHeartbeatResponse.parse(readable, version);
             case SHARE_GROUP_DESCRIBE:
-                return ShareGroupDescribeResponse.parse(responseBuffer, version);
+                return ShareGroupDescribeResponse.parse(readable, version);
             case SHARE_FETCH:
-                return ShareFetchResponse.parse(responseBuffer, version);
+                return ShareFetchResponse.parse(readable, version);
             case SHARE_ACKNOWLEDGE:
-                return ShareAcknowledgeResponse.parse(responseBuffer, version);
+                return ShareAcknowledgeResponse.parse(readable, version);
             case ADD_RAFT_VOTER:
-                return AddRaftVoterResponse.parse(responseBuffer, version);
+                return AddRaftVoterResponse.parse(readable, version);
             case REMOVE_RAFT_VOTER:
-                return RemoveRaftVoterResponse.parse(responseBuffer, version);
+                return RemoveRaftVoterResponse.parse(readable, version);
             case UPDATE_RAFT_VOTER:
-                return UpdateRaftVoterResponse.parse(responseBuffer, version);
+                return UpdateRaftVoterResponse.parse(readable, version);
             case INITIALIZE_SHARE_GROUP_STATE:
-                return InitializeShareGroupStateResponse.parse(responseBuffer, version);
+                return InitializeShareGroupStateResponse.parse(readable, version);
             case READ_SHARE_GROUP_STATE:
-                return ReadShareGroupStateResponse.parse(responseBuffer, version);
+                return ReadShareGroupStateResponse.parse(readable, version);
             case WRITE_SHARE_GROUP_STATE:
-                return WriteShareGroupStateResponse.parse(responseBuffer, version);
+                return WriteShareGroupStateResponse.parse(readable, version);
             case DELETE_SHARE_GROUP_STATE:
-                return DeleteShareGroupStateResponse.parse(responseBuffer, version);
+                return DeleteShareGroupStateResponse.parse(readable, version);
             case READ_SHARE_GROUP_STATE_SUMMARY:
-                return ReadShareGroupStateSummaryResponse.parse(responseBuffer, version);
+                return ReadShareGroupStateSummaryResponse.parse(readable, version);
+            case STREAMS_GROUP_HEARTBEAT:
+                return StreamsGroupHeartbeatResponse.parse(readable, version);
+            case STREAMS_GROUP_DESCRIBE:
+                return StreamsGroupDescribeResponse.parse(readable, version);
+            case DESCRIBE_SHARE_GROUP_OFFSETS:
+                return DescribeShareGroupOffsetsResponse.parse(readable, version);
+            case ALTER_SHARE_GROUP_OFFSETS:
+                return AlterShareGroupOffsetsResponse.parse(readable, version);
+            case DELETE_SHARE_GROUP_OFFSETS:
+                return DeleteShareGroupOffsetsResponse.parse(readable, version);
             default:
                 throw new AssertionError(String.format("ApiKey %s is not currently handled in `parseResponse`, the " +
                         "code should be updated to do so.", apiKey));
