@@ -20,10 +20,8 @@ package org.apache.kafka.common.requests;
 import org.apache.kafka.common.message.GetTelemetrySubscriptionsRequestData;
 import org.apache.kafka.common.message.GetTelemetrySubscriptionsResponseData;
 import org.apache.kafka.common.protocol.ApiKeys;
-import org.apache.kafka.common.protocol.ByteBufferAccessor;
 import org.apache.kafka.common.protocol.Errors;
-
-import java.nio.ByteBuffer;
+import org.apache.kafka.common.protocol.Readable;
 
 public class GetTelemetrySubscriptionsRequest extends AbstractRequest {
 
@@ -71,8 +69,8 @@ public class GetTelemetrySubscriptionsRequest extends AbstractRequest {
         return data;
     }
 
-    public static GetTelemetrySubscriptionsRequest parse(ByteBuffer buffer, short version) {
+    public static GetTelemetrySubscriptionsRequest parse(Readable readable, short version) {
         return new GetTelemetrySubscriptionsRequest(new GetTelemetrySubscriptionsRequestData(
-                new ByteBufferAccessor(buffer), version), version);
+                readable, version), version);
     }
 }
\ No newline at end of file
