@@ -20,6 +20,8 @@ import org.apache.kafka.clients.CommonClientConfigs;
 import org.apache.kafka.common.KafkaException;
 import org.apache.kafka.common.Uuid;
 import org.apache.kafka.common.errors.InterruptException;
+import org.apache.kafka.common.errors.RetriableException;
+import org.apache.kafka.common.errors.UnsupportedVersionException;
 import org.apache.kafka.common.message.GetTelemetrySubscriptionsRequestData;
 import org.apache.kafka.common.message.GetTelemetrySubscriptionsResponseData;
 import org.apache.kafka.common.message.PushTelemetryRequestData;
@@ -526,13 +528,13 @@ public class ClientTelemetryReporter implements MetricsReporter {
         @Override
         public void handleFailedGetTelemetrySubscriptionsRequest(KafkaException maybeFatalException) {
             log.debug("The broker generated an error for the get telemetry network API request", maybeFatalException);
-            handleFailedRequest(maybeFatalException != null);
+            handleFailedRequest(maybeFatalException);
         }
 
         @Override
         public void handleFailedPushTelemetryRequest(KafkaException maybeFatalException) {
             log.debug("The broker generated an error for the push telemetry network API request", maybeFatalException);
-            handleFailedRequest(maybeFatalException != null);
+            handleFailedRequest(maybeFatalException);
         }
 
         @Override
@@ -626,6 +628,12 @@ public class ClientTelemetryReporter implements MetricsReporter {
             }
         }
 
+        private boolean isRetryable(final KafkaException maybeFatalException) {
+            return maybeFatalException == null ||
+                (maybeFatalException instanceof RetriableException) ||
+                (maybeFatalException.getCause() != null && maybeFatalException.getCause() instanceof RetriableException);
+        }
+
         private Optional<Builder<?>> createSubscriptionRequest(ClientTelemetrySubscription localSubscription) {
             /*
              If we've previously retrieved a subscription, it will contain the client instance ID
@@ -827,7 +835,7 @@ public class ClientTelemetryReporter implements MetricsReporter {
             }
         }
 
-        private void handleFailedRequest(boolean shouldWait) {
+        private void handleFailedRequest(KafkaException maybeFatalException) {
             final long nowMs = time.milliseconds();
             lock.writeLock().lock();
             try {
@@ -845,10 +853,12 @@ public class ClientTelemetryReporter implements MetricsReporter {
                  again. We may disconnect from the broker and connect to a broker that supports client
                  telemetry.
                 */
-                if (shouldWait) {
+                if (isRetryable(maybeFatalException)) {
                     updateErrorResult(DEFAULT_PUSH_INTERVAL_MS, nowMs);
                 } else {
-                    log.warn("Received unrecoverable error from broker, disabling telemetry");
+                    if (!(maybeFatalException instanceof UnsupportedVersionException)) {
+                        log.warn("Received unrecoverable error from broker, disabling telemetry");
+                    }
                     updateErrorResult(Integer.MAX_VALUE, nowMs);
                 }
 
