@@ -26,11 +26,17 @@ import org.apache.kafka.common.Node;
 import org.apache.kafka.common.TopicPartition;
 import org.apache.kafka.common.Uuid;
 import org.apache.kafka.common.errors.GroupAuthorizationException;
+import org.apache.kafka.common.errors.InvalidCommitOffsetSizeException;
+import org.apache.kafka.common.errors.OffsetMetadataTooLarge;
 import org.apache.kafka.common.errors.RetriableException;
+import org.apache.kafka.common.errors.StaleMemberEpochException;
 import org.apache.kafka.common.errors.TimeoutException;
+import org.apache.kafka.common.errors.TopicAuthorizationException;
+import org.apache.kafka.common.errors.UnknownMemberIdException;
 import org.apache.kafka.common.message.OffsetCommitRequestData;
 import org.apache.kafka.common.message.OffsetCommitResponseData;
 import org.apache.kafka.common.message.OffsetFetchRequestData;
+import org.apache.kafka.common.message.OffsetFetchResponseData;
 import org.apache.kafka.common.metrics.KafkaMetric;
 import org.apache.kafka.common.metrics.Metrics;
 import org.apache.kafka.common.protocol.ApiKeys;
@@ -424,16 +430,6 @@ public class CommitRequestManagerTest {
         assertExceptionHandling(commitRequestManager, error, true);
     }
 
-    private static Stream<Arguments> commitSyncExpectedExceptions() {
-        return Stream.of(
-            Arguments.of(Errors.UNKNOWN_MEMBER_ID, CommitFailedException.class),
-            Arguments.of(Errors.OFFSET_METADATA_TOO_LARGE, Errors.OFFSET_METADATA_TOO_LARGE.exception().getClass()),
-            Arguments.of(Errors.INVALID_COMMIT_OFFSET_SIZE, Errors.INVALID_COMMIT_OFFSET_SIZE.exception().getClass()),
-            Arguments.of(Errors.GROUP_AUTHORIZATION_FAILED, Errors.GROUP_AUTHORIZATION_FAILED.exception().getClass()),
-            Arguments.of(Errors.CORRUPT_MESSAGE, KafkaException.class),
-            Arguments.of(Errors.UNKNOWN_SERVER_ERROR, KafkaException.class));
-    }
-
     @Test
     public void testCommitSyncFailsWithCommitFailedExceptionIfUnknownMemberId() {
         CommitRequestManager commitRequestManager = create(false, 100);
@@ -449,7 +445,7 @@ public class CommitRequestManagerTest {
         NetworkClientDelegate.PollResult res = commitRequestManager.poll(time.milliseconds());
         assertEquals(0, res.unsentRequests.size());
         assertTrue(commitResult.isDone());
-        assertFutureThrows(commitResult, CommitFailedException.class);
+        assertFutureThrows(CommitFailedException.class, commitResult);
     }
 
     @Test
@@ -470,7 +466,7 @@ public class CommitRequestManagerTest {
 
         // Commit should fail with CommitFailedException
         assertTrue(commitResult.isDone());
-        assertFutureThrows(commitResult, CommitFailedException.class);
+        assertFutureThrows(CommitFailedException.class, commitResult);
     }
 
     /**
@@ -524,7 +520,7 @@ public class CommitRequestManagerTest {
 
         // Commit should mark the coordinator unknown and fail with RetriableCommitFailedException.
         assertTrue(commitResult.isDone());
-        assertFutureThrows(commitResult, RetriableCommitFailedException.class);
+        assertFutureThrows(RetriableCommitFailedException.class, commitResult);
         assertCoordinatorDisconnectHandling();
     }
 
@@ -722,7 +718,8 @@ public class CommitRequestManagerTest {
 
     @ParameterizedTest
     @MethodSource("offsetFetchExceptionSupplier")
-    public void testOffsetFetchRequestTimeoutRequests(final Errors error) {
+    public void testOffsetFetchRequestTimeoutRequests(final Errors error, 
+                                                     final Class<? extends Exception> expectedExceptionClass) {
         CommitRequestManager commitRequestManager = create(true, 100);
         when(coordinatorRequestManager.coordinator()).thenReturn(Optional.of(mockedNode));
 
@@ -743,10 +740,10 @@ public class CommitRequestManagerTest {
             assertFalse(commitRequestManager.pendingRequests.unsentOffsetFetches.isEmpty());
             NetworkClientDelegate.PollResult poll = commitRequestManager.poll(time.milliseconds());
             mimicResponse(error, poll);
-            futures.forEach(f -> assertFutureThrows(f, TimeoutException.class));
+            futures.forEach(f -> assertFutureThrows(expectedExceptionClass, f));
             assertTrue(commitRequestManager.pendingRequests.unsentOffsetFetches.isEmpty());
         } else {
-            futures.forEach(f -> assertFutureThrows(f, KafkaException.class));
+            futures.forEach(f -> assertFutureThrows(expectedExceptionClass, f));
             assertEmptyPendingRequests(commitRequestManager);
         }
     }
@@ -756,10 +753,10 @@ public class CommitRequestManagerTest {
         CommitRequestManager commitManager = create(false, 100);
         when(coordinatorRequestManager.coordinator()).thenReturn(Optional.of(mockedNode));
 
+        TopicPartition tp = new TopicPartition("topic1", 0);
         long deadlineMs = time.milliseconds() + defaultApiTimeoutMs;
         CompletableFuture<Map<TopicPartition, OffsetAndMetadata>> fetchResult =
-            commitManager.fetchOffsets(Collections.singleton(new TopicPartition("test", 0)),
-                deadlineMs);
+            commitManager.fetchOffsets(Collections.singleton(tp), deadlineMs);
 
         // Send fetch request
         NetworkClientDelegate.PollResult result = commitManager.poll(time.milliseconds());
@@ -768,14 +765,21 @@ public class CommitRequestManagerTest {
         assertFalse(fetchResult.isDone());
 
         // Complete request with a response
-        TopicPartition tp = new TopicPartition("topic1", 0);
         long expectedOffset = 100;
         NetworkClientDelegate.UnsentRequest req = result.unsentRequests.get(0);
-        Map<TopicPartition, OffsetFetchResponse.PartitionData> topicPartitionData =
-            Collections.singletonMap(
-                tp,
-                new OffsetFetchResponse.PartitionData(expectedOffset, Optional.of(1), "", Errors.NONE));
-        req.handler().onComplete(buildOffsetFetchClientResponse(req, topicPartitionData, Errors.NONE, false));
+        OffsetFetchResponseData.OffsetFetchResponseGroup groupResponse = new OffsetFetchResponseData.OffsetFetchResponseGroup()
+            .setGroupId(DEFAULT_GROUP_ID)
+            .setTopics(List.of(
+                new OffsetFetchResponseData.OffsetFetchResponseTopics()
+                    .setName(tp.topic())
+                    .setPartitions(List.of(
+                        new OffsetFetchResponseData.OffsetFetchResponsePartitions()
+                            .setPartitionIndex(tp.partition())
+                            .setCommittedOffset(expectedOffset)
+                            .setCommittedLeaderEpoch(1)
+                    ))
+            ));
+        req.handler().onComplete(buildOffsetFetchClientResponse(req, groupResponse, false));
 
         // Validate request future completes with the response received
         assertTrue(fetchResult.isDone());
@@ -868,7 +872,7 @@ public class CommitRequestManagerTest {
         assertTrue(commitResult.isDone());
         assertTrue(commitResult.isCompletedExceptionally());
         if (error.exception() instanceof RetriableException) {
-            assertFutureThrows(commitResult, RetriableCommitFailedException.class);
+            assertFutureThrows(RetriableCommitFailedException.class, commitResult);
         }
 
         // We expect that the request should not have been retried on this async commit.
@@ -909,7 +913,9 @@ public class CommitRequestManagerTest {
      */
     @ParameterizedTest
     @MethodSource("offsetCommitExceptionSupplier")
-    public void testOffsetCommitSyncFailedWithRetriableThrowsTimeoutWhenRetryTimeExpires(final Errors error) {
+    public void testOffsetCommitSyncFailedWithRetriableThrowsTimeoutWhenRetryTimeExpires(
+            final Errors error, 
+            final Class<? extends Exception> expectedExceptionClass) {
         CommitRequestManager commitRequestManager = create(false, 100);
         when(coordinatorRequestManager.coordinator()).thenReturn(Optional.of(mockedNode));
 
@@ -929,10 +935,7 @@ public class CommitRequestManagerTest {
         assertEquals(0, res.unsentRequests.size());
         assertTrue(commitResult.isDone());
 
-        if (error.exception() instanceof RetriableException)
-            assertFutureThrows(commitResult, TimeoutException.class);
-        else
-            assertFutureThrows(commitResult, KafkaException.class);
+        assertFutureThrows(expectedExceptionClass, commitResult);
     }
 
     /**
@@ -960,7 +963,7 @@ public class CommitRequestManagerTest {
         assertExceptionHandling(commitRequestManager, retriableError, false);
 
         // Request should complete with a RetriableCommitException
-        assertFutureThrows(commitResult, RetriableCommitFailedException.class);
+        assertFutureThrows(RetriableCommitFailedException.class, commitResult);
     }
 
     @ParameterizedTest
@@ -1310,7 +1313,7 @@ public class CommitRequestManagerTest {
         mimicResponse(error, poll);
         futures.forEach(f -> {
             assertTrue(f.isCompletedExceptionally());
-            assertFutureThrows(f, TimeoutException.class);
+            assertFutureThrows(TimeoutException.class, f);
         });
     }
 
@@ -1327,18 +1330,23 @@ public class CommitRequestManagerTest {
      */
     private static Stream<Arguments> offsetCommitExceptionSupplier() {
         return Stream.of(
-            Arguments.of(Errors.NOT_COORDINATOR),
-            Arguments.of(Errors.COORDINATOR_LOAD_IN_PROGRESS),
-            Arguments.of(Errors.UNKNOWN_SERVER_ERROR),
-            Arguments.of(Errors.GROUP_AUTHORIZATION_FAILED),
-            Arguments.of(Errors.OFFSET_METADATA_TOO_LARGE),
-            Arguments.of(Errors.INVALID_COMMIT_OFFSET_SIZE),
-            Arguments.of(Errors.UNKNOWN_TOPIC_OR_PARTITION),
-            Arguments.of(Errors.COORDINATOR_NOT_AVAILABLE),
-            Arguments.of(Errors.REQUEST_TIMED_OUT),
-            Arguments.of(Errors.TOPIC_AUTHORIZATION_FAILED),
-            Arguments.of(Errors.STALE_MEMBER_EPOCH),
-            Arguments.of(Errors.UNKNOWN_MEMBER_ID));
+            // Retriable errors should result in TimeoutException when retry time expires
+            Arguments.of(Errors.NOT_COORDINATOR, TimeoutException.class),
+            Arguments.of(Errors.COORDINATOR_LOAD_IN_PROGRESS, TimeoutException.class),
+            Arguments.of(Errors.COORDINATOR_NOT_AVAILABLE, TimeoutException.class),
+            Arguments.of(Errors.REQUEST_TIMED_OUT, TimeoutException.class),
+            Arguments.of(Errors.UNKNOWN_TOPIC_OR_PARTITION, TimeoutException.class),
+            
+            // Non-retriable errors should result in their specific exceptions
+            Arguments.of(Errors.GROUP_AUTHORIZATION_FAILED, GroupAuthorizationException.class),
+            Arguments.of(Errors.OFFSET_METADATA_TOO_LARGE, OffsetMetadataTooLarge.class),
+            Arguments.of(Errors.INVALID_COMMIT_OFFSET_SIZE, InvalidCommitOffsetSizeException.class),
+            Arguments.of(Errors.TOPIC_AUTHORIZATION_FAILED, TopicAuthorizationException.class),
+            Arguments.of(Errors.UNKNOWN_MEMBER_ID, CommitFailedException.class),
+            Arguments.of(Errors.STALE_MEMBER_EPOCH, CommitFailedException.class),
+            
+            // Generic errors should result in KafkaException
+            Arguments.of(Errors.UNKNOWN_SERVER_ERROR, KafkaException.class));
     }
 
     /**
@@ -1346,21 +1354,27 @@ public class CommitRequestManagerTest {
      */
     private static Stream<Arguments> offsetFetchExceptionSupplier() {
         return Stream.of(
-            Arguments.of(Errors.NOT_COORDINATOR),
-            Arguments.of(Errors.COORDINATOR_LOAD_IN_PROGRESS),
-            Arguments.of(Errors.UNKNOWN_SERVER_ERROR),
-            Arguments.of(Errors.GROUP_AUTHORIZATION_FAILED),
-            Arguments.of(Errors.OFFSET_METADATA_TOO_LARGE),
-            Arguments.of(Errors.INVALID_COMMIT_OFFSET_SIZE),
-            Arguments.of(Errors.UNKNOWN_TOPIC_OR_PARTITION),
-            Arguments.of(Errors.COORDINATOR_NOT_AVAILABLE),
-            Arguments.of(Errors.REQUEST_TIMED_OUT),
-            Arguments.of(Errors.TOPIC_AUTHORIZATION_FAILED),
-            Arguments.of(Errors.UNKNOWN_MEMBER_ID),
+            // Retriable errors should result in TimeoutException when retry time expires
+            Arguments.of(Errors.NOT_COORDINATOR, TimeoutException.class),
+            Arguments.of(Errors.COORDINATOR_LOAD_IN_PROGRESS, TimeoutException.class),
+            Arguments.of(Errors.COORDINATOR_NOT_AVAILABLE, TimeoutException.class),
+            Arguments.of(Errors.REQUEST_TIMED_OUT, TimeoutException.class),
+            Arguments.of(Errors.UNSTABLE_OFFSET_COMMIT, TimeoutException.class),
+            Arguments.of(Errors.UNKNOWN_TOPIC_OR_PARTITION, TimeoutException.class),
+            
+            // Non-retriable errors should result in their specific exceptions
+            Arguments.of(Errors.GROUP_AUTHORIZATION_FAILED, GroupAuthorizationException.class),
+            Arguments.of(Errors.OFFSET_METADATA_TOO_LARGE, KafkaException.class),
+            Arguments.of(Errors.INVALID_COMMIT_OFFSET_SIZE, KafkaException.class),
+
+            Arguments.of(Errors.TOPIC_AUTHORIZATION_FAILED, KafkaException.class),
+            Arguments.of(Errors.UNKNOWN_MEMBER_ID, UnknownMemberIdException.class),
             // Adding STALE_MEMBER_EPOCH as non-retriable here because it is only retried if a new
             // member epoch is received. Tested separately.
-            Arguments.of(Errors.STALE_MEMBER_EPOCH),
-            Arguments.of(Errors.UNSTABLE_OFFSET_COMMIT));
+            Arguments.of(Errors.STALE_MEMBER_EPOCH, StaleMemberEpochException.class),
+            
+            // Generic errors should result in KafkaException
+            Arguments.of(Errors.UNKNOWN_SERVER_ERROR, KafkaException.class));
     }
 
     /**
@@ -1394,15 +1408,43 @@ public class CommitRequestManagerTest {
         assertEquals(1, res.unsentRequests.size());
 
         // Setting 1 partition with error
-        HashMap<TopicPartition, OffsetFetchResponse.PartitionData> topicPartitionData = new HashMap<>();
-        topicPartitionData.put(tp1, new OffsetFetchResponse.PartitionData(100L, Optional.of(1), "metadata", error));
-        topicPartitionData.put(tp2, new OffsetFetchResponse.PartitionData(100L, Optional.of(1), "metadata", Errors.NONE));
-        topicPartitionData.put(tp3, new OffsetFetchResponse.PartitionData(100L, Optional.of(1), "metadata", error));
+        OffsetFetchResponseData.OffsetFetchResponseGroup groupResponse = new OffsetFetchResponseData.OffsetFetchResponseGroup()
+            .setGroupId(DEFAULT_GROUP_ID)
+            .setTopics(List.of(
+                new OffsetFetchResponseData.OffsetFetchResponseTopics()
+                    .setName(tp1.topic())
+                    .setPartitions(List.of(
+                        new OffsetFetchResponseData.OffsetFetchResponsePartitions()
+                            .setPartitionIndex(tp1.partition())
+                            .setCommittedOffset(100L)
+                            .setCommittedLeaderEpoch(1)
+                            .setMetadata("metadata")
+                            .setErrorCode(error.code())
+                    )),
+                new OffsetFetchResponseData.OffsetFetchResponseTopics()
+                    .setName(tp2.topic())
+                    .setPartitions(List.of(
+                        new OffsetFetchResponseData.OffsetFetchResponsePartitions()
+                            .setPartitionIndex(tp2.partition())
+                            .setCommittedOffset(100L)
+                            .setCommittedLeaderEpoch(1)
+                            .setMetadata("metadata")
+                    )),
+                new OffsetFetchResponseData.OffsetFetchResponseTopics()
+                    .setName(tp3.topic())
+                    .setPartitions(List.of(
+                        new OffsetFetchResponseData.OffsetFetchResponsePartitions()
+                            .setPartitionIndex(tp3.partition())
+                            .setCommittedOffset(100L)
+                            .setCommittedLeaderEpoch(1)
+                            .setMetadata("metadata")
+                            .setErrorCode(error.code())
+                    ))
+            ));
 
         res.unsentRequests.get(0).handler().onComplete(buildOffsetFetchClientResponse(
                 res.unsentRequests.get(0),
-                topicPartitionData,
-                Errors.NONE,
+                groupResponse,
                 false));
         if (isRetriable)
             testRetriable(commitRequestManager, Collections.singletonList(future), error);
@@ -1543,18 +1585,26 @@ public class CommitRequestManagerTest {
             final NetworkClientDelegate.UnsentRequest request,
             final Set<TopicPartition> topicPartitions,
             final Errors error) {
-        HashMap<TopicPartition, OffsetFetchResponse.PartitionData> topicPartitionData = new HashMap<>();
-        topicPartitions.forEach(tp -> topicPartitionData.put(tp, new OffsetFetchResponse.PartitionData(
-                100L,
-                Optional.of(1),
-                "metadata",
-                Errors.NONE)));
-        return buildOffsetFetchClientResponse(request, topicPartitionData, error, false);
+        OffsetFetchResponseData.OffsetFetchResponseGroup group = new OffsetFetchResponseData.OffsetFetchResponseGroup()
+            .setGroupId(DEFAULT_GROUP_ID)
+            .setErrorCode(error.code())
+            .setTopics(topicPartitions.stream().collect(Collectors.groupingBy(TopicPartition::topic)).entrySet().stream().map(entry ->
+                new OffsetFetchResponseData.OffsetFetchResponseTopics()
+                    .setName(entry.getKey())
+                    .setPartitions(entry.getValue().stream().map(partition ->
+                        new OffsetFetchResponseData.OffsetFetchResponsePartitions()
+                            .setPartitionIndex(partition.partition())
+                            .setCommittedOffset(100L)
+                            .setCommittedLeaderEpoch(1)
+                            .setMetadata("metadata")
+                    ).collect(Collectors.toList()))
+             ).collect(Collectors.toList()));
+        return buildOffsetFetchClientResponse(request, group, false);
     }
 
     private ClientResponse buildOffsetFetchClientResponseDisconnected(
         final NetworkClientDelegate.UnsentRequest request) {
-        return buildOffsetFetchClientResponse(request, Collections.emptyMap(), Errors.NONE, true);
+        return buildOffsetFetchClientResponse(request, new OffsetFetchResponseData.OffsetFetchResponseGroup(), true);
     }
 
     private ClientResponse buildOffsetCommitClientResponse(final OffsetCommitResponse commitResponse) {
@@ -1670,14 +1720,12 @@ public class CommitRequestManagerTest {
 
     private ClientResponse buildOffsetFetchClientResponse(
             final NetworkClientDelegate.UnsentRequest request,
-            final Map<TopicPartition, OffsetFetchResponse.PartitionData> topicPartitionData,
-            final Errors error,
+            final OffsetFetchResponseData.OffsetFetchResponseGroup groupResponse,
             final boolean disconnected) {
         AbstractRequest abstractRequest = request.requestBuilder().build();
         assertInstanceOf(OffsetFetchRequest.class, abstractRequest);
         OffsetFetchRequest offsetFetchRequest = (OffsetFetchRequest) abstractRequest;
-        OffsetFetchResponse response =
-                new OffsetFetchResponse(error, topicPartitionData);
+        OffsetFetchResponse response = new OffsetFetchResponse.Builder(groupResponse).build(ApiKeys.OFFSET_FETCH.latestVersion());
         return new ClientResponse(
                 new RequestHeader(ApiKeys.OFFSET_FETCH, offsetFetchRequest.version(), "", 1),
                 request.handler(),
