@@ -21,6 +21,7 @@ import org.apache.kafka.clients.consumer.internals.events.ApplicationEventProces
 import org.apache.kafka.clients.consumer.internals.events.CompletableEventReaper;
 import org.apache.kafka.clients.consumer.internals.events.PollEvent;
 import org.apache.kafka.clients.consumer.internals.metrics.AsyncConsumerMetrics;
+import org.apache.kafka.common.KafkaException;
 import org.apache.kafka.common.metrics.Metrics;
 import org.apache.kafka.common.utils.LogContext;
 import org.apache.kafka.common.utils.MockTime;
@@ -35,18 +36,18 @@ import org.junit.jupiter.params.ParameterizedTest;
 import org.junit.jupiter.params.provider.ValueSource;
 
 import java.time.Duration;
-import java.util.ArrayList;
-import java.util.Collections;
 import java.util.LinkedList;
 import java.util.List;
-import java.util.Optional;
 import java.util.concurrent.BlockingQueue;
 import java.util.concurrent.LinkedBlockingQueue;
+import java.util.function.Supplier;
 
 import static org.apache.kafka.clients.consumer.internals.ConsumerUtils.CONSUMER_METRIC_GROUP;
 import static org.apache.kafka.test.TestUtils.DEFAULT_MAX_WAIT_MS;
+import static org.junit.jupiter.api.Assertions.assertDoesNotThrow;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.ArgumentMatchers.anyLong;
@@ -117,10 +118,7 @@ public class ConsumerNetworkThreadTest {
     @ParameterizedTest
     @ValueSource(longs = {ConsumerNetworkThread.MAX_POLL_TIMEOUT_MS - 1, ConsumerNetworkThread.MAX_POLL_TIMEOUT_MS, ConsumerNetworkThread.MAX_POLL_TIMEOUT_MS + 1})
     public void testConsumerNetworkThreadPollTimeComputations(long exampleTime) {
-        List<Optional<? extends RequestManager>> list = new ArrayList<>();
-        list.add(Optional.of(coordinatorRequestManager));
-        list.add(Optional.of(heartbeatRequestManager));
-
+        List<RequestManager> list = List.of(coordinatorRequestManager, heartbeatRequestManager);
         when(requestManagers.entries()).thenReturn(list);
 
         NetworkClientDelegate.PollResult pollResult = new NetworkClientDelegate.PollResult(exampleTime);
@@ -158,16 +156,13 @@ public class ConsumerNetworkThreadTest {
 
     @Test
     public void testRequestsTransferFromManagersToClientOnThreadRun() {
-        List<Optional<? extends RequestManager>> list = new ArrayList<>();
-        list.add(Optional.of(coordinatorRequestManager));
-        list.add(Optional.of(heartbeatRequestManager));
-        list.add(Optional.of(offsetsRequestManager));
+        List<RequestManager> list = List.of(coordinatorRequestManager, heartbeatRequestManager, offsetsRequestManager);
 
         when(requestManagers.entries()).thenReturn(list);
         when(coordinatorRequestManager.poll(anyLong())).thenReturn(mock(NetworkClientDelegate.PollResult.class));
         consumerNetworkThread.runOnce();
-        requestManagers.entries().forEach(rmo -> rmo.ifPresent(rm -> verify(rm).poll(anyLong())));
-        requestManagers.entries().forEach(rmo -> rmo.ifPresent(rm -> verify(rm).maximumTimeToWait(anyLong())));
+        requestManagers.entries().forEach(rm -> verify(rm).poll(anyLong()));
+        requestManagers.entries().forEach(rm -> verify(rm).maximumTimeToWait(anyLong()));
         verify(networkClientDelegate).addAll(any(NetworkClientDelegate.PollResult.class));
         verify(networkClientDelegate).poll(anyLong(), anyLong());
     }
@@ -178,7 +173,7 @@ public class ConsumerNetworkThreadTest {
         // Initial value before runOnce has been called
         assertEquals(ConsumerNetworkThread.MAX_POLL_TIMEOUT_MS, consumerNetworkThread.maximumTimeToWait());
 
-        when(requestManagers.entries()).thenReturn(Collections.singletonList(Optional.of(heartbeatRequestManager)));
+        when(requestManagers.entries()).thenReturn(List.of(heartbeatRequestManager));
         when(heartbeatRequestManager.maximumTimeToWait(time.milliseconds())).thenReturn((long) defaultHeartbeatIntervalMs);
 
         consumerNetworkThread.runOnce();
@@ -288,4 +283,57 @@ public class ConsumerNetworkThreadTest {
             );
         }
     }
+
+    @Test
+    public void testNetworkClientDelegateInitializeResourcesError() {
+        Supplier<NetworkClientDelegate> networkClientDelegateSupplier = () -> {
+            throw new KafkaException("Injecting NetworkClientDelegate initialization failure");
+        };
+        Supplier<RequestManagers> requestManagersSupplier = () -> requestManagers;
+        testInitializeResourcesError(networkClientDelegateSupplier, requestManagersSupplier);
+    }
+
+    @Test
+    public void testRequestManagersInitializeResourcesError() {
+        Supplier<NetworkClientDelegate> networkClientDelegateSupplier = () -> networkClientDelegate;
+        Supplier<RequestManagers> requestManagersSupplier = () -> {
+            throw new KafkaException("Injecting RequestManagers initialization failure");
+        };
+        testInitializeResourcesError(networkClientDelegateSupplier, requestManagersSupplier);
+    }
+
+    @Test
+    public void testNetworkClientDelegateAndRequestManagersInitializeResourcesError() {
+        Supplier<NetworkClientDelegate> networkClientDelegateSupplier = () -> {
+            throw new KafkaException("Injecting NetworkClientDelegate initialization failure");
+        };
+        Supplier<RequestManagers> requestManagersSupplier = () -> {
+            throw new KafkaException("Injecting RequestManagers initialization failure");
+        };
+        testInitializeResourcesError(networkClientDelegateSupplier, requestManagersSupplier);
+    }
+
+    /**
+     * Tests that when an error occurs during {@link ConsumerNetworkThread#initializeResources()} that the
+     * logic in {@link ConsumerNetworkThread#cleanup()} will not throw errors when closing.
+     */
+    private void testInitializeResourcesError(Supplier<NetworkClientDelegate> networkClientDelegateSupplier,
+                                              Supplier<RequestManagers> requestManagersSupplier) {
+        // A new ConsumerNetworkThread is created because the shared one doesn't have any issues initializing its
+        // resources. However, most of the mocks can be reused, so this is mostly boilerplate except for the error
+        // when a supplier is invoked.
+        try (ConsumerNetworkThread thread = new ConsumerNetworkThread(
+            new LogContext(),
+            time,
+            applicationEventQueue,
+            applicationEventReaper,
+            () -> applicationEventProcessor,
+            networkClientDelegateSupplier,
+            requestManagersSupplier,
+            asyncConsumerMetrics
+        )) {
+            assertThrows(KafkaException.class, thread::initializeResources, "initializeResources should fail because one or more Supplier throws an error on get()");
+            assertDoesNotThrow(thread::cleanup, "cleanup() should not cause an error because all references are checked before use");
+        }
+    }
 }
