@@ -236,8 +236,8 @@ public class ShareFetchCollectorTest {
 
         ConsumerConfig config = new ConsumerConfig(p);
 
-        deserializers = new Deserializers<>(new StringDeserializer(), new StringDeserializer());
         Metrics metrics = createMetrics(config, Time.SYSTEM);
+        deserializers = new Deserializers<>(new StringDeserializer(), new StringDeserializer(), metrics);
         ShareFetchMetricsManager shareFetchMetricsManager = createShareFetchMetricsManager(metrics);
         Set<TopicPartition> partitionSet = new HashSet<>();
         partitionSet.add(topicAPartition0.topicPartition());
@@ -347,6 +347,7 @@ public class ShareFetchCollectorTest {
             return new ShareCompletedFetch(
                     logContext,
                     BufferSupplier.create(),
+                    0,
                     topicAPartition0,
                     partitionData,
                     shareFetchMetricsAggregator,
