@@ -23,7 +23,6 @@ import org.apache.kafka.common.TopicPartition;
 import org.apache.kafka.common.Uuid;
 import org.apache.kafka.common.message.ShareGroupHeartbeatResponseData;
 import org.apache.kafka.common.message.ShareGroupHeartbeatResponseData.Assignment;
-import org.apache.kafka.common.metrics.KafkaMetric;
 import org.apache.kafka.common.metrics.Metrics;
 import org.apache.kafka.common.protocol.Errors;
 import org.apache.kafka.common.requests.ShareGroupHeartbeatRequest;
@@ -57,7 +56,6 @@ import java.util.stream.Collectors;
 import java.util.stream.Stream;
 
 import static org.apache.kafka.clients.consumer.internals.AbstractMembershipManager.TOPIC_PARTITION_COMPARATOR;
-import static org.apache.kafka.clients.consumer.internals.ConsumerUtils.CONSUMER_SHARE_METRIC_GROUP_PREFIX;
 import static org.apache.kafka.common.requests.ShareGroupHeartbeatRequest.LEAVE_GROUP_MEMBER_EPOCH;
 import static org.apache.kafka.common.utils.Utils.mkEntry;
 import static org.apache.kafka.common.utils.Utils.mkMap;
@@ -314,6 +312,10 @@ public class ShareMembershipManagerTest {
 
         membershipManager.onHeartbeatSuccess(createShareGroupHeartbeatResponse(new ShareGroupHeartbeatResponseData.Assignment(), membershipManager.memberId()));
 
+        assertFalse(sendLeave.isDone(), "Send leave operation should not complete until a leave response is received");
+
+        membershipManager.onHeartbeatSuccess(createShareGroupLeaveResponse(membershipManager.memberId()));
+
         assertSendLeaveCompleted(membershipManager, sendLeave);
     }
 
@@ -520,6 +522,9 @@ public class ShareMembershipManagerTest {
         assertFalse(leaveResult.isDone());
 
         membershipManager.onHeartbeatSuccess(createShareGroupHeartbeatResponse(createAssignment(true), membershipManager.memberId()));
+        assertFalse(leaveResult.isDone());
+
+        membershipManager.onHeartbeatSuccess(createShareGroupLeaveResponse(membershipManager.memberId()));
         assertSendLeaveCompleted(membershipManager, leaveResult);
     }
 
@@ -563,10 +568,46 @@ public class ShareMembershipManagerTest {
 
         assertEquals(state, membershipManager.state());
         verify(responseData, never()).memberId();
-        verify(responseData, never()).memberEpoch();
+        // In unsubscribed, we check if we received a leave group response, so we do verify member epoch.
+        if (state != MemberState.UNSUBSCRIBED) {
+            verify(responseData, never()).memberEpoch();
+        }
         verify(responseData, never()).assignment();
     }
 
+    @Test
+    public void testIgnoreLeaveResponseWhenNotLeavingGroup() {
+        ShareMembershipManager membershipManager = createMemberInStableState();
+
+        CompletableFuture<Void> leaveResult = membershipManager.leaveGroup();
+
+        // Send leave request, transitioning to UNSUBSCRIBED state
+        membershipManager.onHeartbeatRequestGenerated();
+        assertEquals(MemberState.UNSUBSCRIBED, membershipManager.state());
+
+        // Receive a previous heartbeat response, which should be ignored
+        membershipManager.onHeartbeatSuccess(new ShareGroupHeartbeatResponse(
+            new ShareGroupHeartbeatResponseData()
+                .setErrorCode(Errors.NONE.code())
+                .setMemberId(membershipManager.memberId())
+                .setMemberEpoch(MEMBER_EPOCH)
+        ));
+        assertFalse(leaveResult.isDone());
+
+        // Receive a leave heartbeat response, which should unblock the consumer
+        membershipManager.onHeartbeatSuccess(createShareGroupLeaveResponse(membershipManager.memberId()));
+        assertTrue(leaveResult.isDone());
+
+        // Share unblocks and updates subscription
+        membershipManager.onSubscriptionUpdated();
+        membershipManager.onConsumerPoll();
+
+        membershipManager.onHeartbeatSuccess(createShareGroupLeaveResponse(membershipManager.memberId()));
+
+        assertEquals(MemberState.JOINING, membershipManager.state());
+        assertEquals(0, membershipManager.memberEpoch());
+    }
+
     @Test
     public void testLeaveGroupWhenStateIsReconciling() {
         ShareMembershipManager membershipManager = mockJoinAndReceiveAssignment(false);
@@ -945,7 +986,6 @@ public class ShareMembershipManagerTest {
 
     @Test
     public void testReconcileNewPartitionsAssignedWhenOtherPartitionsOwned() {
-        // ANDREW MANGLED THIS
         Uuid topicId = Uuid.randomUuid();
         String topicName = "topic1";
         TopicIdPartition ownedPartition = new TopicIdPartition(topicId, new TopicPartition(topicName, 0));
@@ -1228,23 +1268,6 @@ public class ShareMembershipManagerTest {
         return membershipManager;
     }
 
-    private void mockPartitionOwnedAndNewPartitionAdded(String topicName,
-                                                        int partitionOwned,
-                                                        int partitionAdded,
-                                                        CounterConsumerRebalanceListener listener,
-                                                        ShareMembershipManager membershipManager) {
-        Uuid topicId = Uuid.randomUuid();
-        TopicPartition owned = new TopicPartition(topicName, partitionOwned);
-        when(subscriptionState.assignedPartitions()).thenReturn(Collections.singleton(owned));
-        membershipManager.updateAssignment(Collections.singletonMap(topicId, mkSortedSet(partitionOwned)));
-        when(metadata.topicNames()).thenReturn(Collections.singletonMap(topicId, topicName));
-        when(subscriptionState.hasAutoAssignedPartitions()).thenReturn(true);
-        when(subscriptionState.rebalanceListener()).thenReturn(Optional.ofNullable(listener));
-
-        // Receive assignment adding a new partition
-        receiveAssignment(topicId, Arrays.asList(partitionOwned, partitionAdded), membershipManager);
-    }
-
     private SortedSet<TopicIdPartition> topicIdPartitionsSet(Uuid topicId, String topicName, int... partitions) {
         SortedSet<TopicIdPartition> topicIdPartitions = new TreeSet<>(new Utils.TopicIdPartitionComparator());
 
@@ -1573,17 +1596,6 @@ public class ShareMembershipManagerTest {
         doNothing().when(subscriptionState).markPendingRevocation(anySet());
     }
 
-    private void mockPrepareLeaving(ShareMembershipManager membershipManager) {
-        String topicName = "topic1";
-        TopicPartition ownedPartition = new TopicPartition(topicName, 0);
-
-        // Start leaving group, blocked waiting for callback to complete.
-        when(subscriptionState.assignedPartitions()).thenReturn(Collections.singleton(ownedPartition));
-        when(subscriptionState.hasAutoAssignedPartitions()).thenReturn(true);
-        doNothing().when(subscriptionState).markPendingRevocation(anySet());
-        membershipManager.leaveGroup();
-    }
-
     private void testStateUpdateOnFatalFailure(ShareMembershipManager membershipManager) {
         String memberId = membershipManager.memberId();
         int lastEpoch = membershipManager.memberEpoch();
@@ -1608,6 +1620,13 @@ public class ShareMembershipManagerTest {
                 .setMemberEpoch(MEMBER_EPOCH)
                 .setAssignment(assignment));
     }
+    
+    private ShareGroupHeartbeatResponse createShareGroupLeaveResponse(String memberId) {
+        return new ShareGroupHeartbeatResponse(new ShareGroupHeartbeatResponseData()
+            .setErrorCode(Errors.NONE.code())
+            .setMemberId(memberId)
+            .setMemberEpoch(ShareGroupHeartbeatRequest.LEAVE_GROUP_MEMBER_EPOCH));
+    }
 
     private ShareGroupHeartbeatResponse createShareGroupHeartbeatResponseWithError(String memberId) {
         return new ShareGroupHeartbeatResponse(new ShareGroupHeartbeatResponseData()
@@ -1641,10 +1660,6 @@ public class ShareMembershipManagerTest {
                 ));
     }
 
-    private KafkaMetric getMetric(final String name) {
-        return metrics.metrics().get(metrics.metricName(name, CONSUMER_SHARE_METRIC_GROUP_PREFIX + "-coordinator-metrics"));
-    }
-
     private ShareMembershipManager memberJoinWithAssignment() {
         Uuid topicId = Uuid.randomUuid();
         ShareMembershipManager membershipManager = mockJoinAndReceiveAssignment(true);
