@@ -26,6 +26,7 @@ import org.apache.kafka.clients.consumer.internals.SubscriptionState.LogTruncati
 import org.apache.kafka.common.IsolationLevel;
 import org.apache.kafka.common.Node;
 import org.apache.kafka.common.TopicPartition;
+import org.apache.kafka.common.Uuid;
 import org.apache.kafka.common.message.OffsetForLeaderEpochResponseData.EpochEndOffset;
 import org.apache.kafka.common.protocol.ApiKeys;
 import org.apache.kafka.common.utils.LogContext;
@@ -37,9 +38,12 @@ import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.HashSet;
+import java.util.List;
 import java.util.Optional;
 import java.util.Set;
+import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.function.LongSupplier;
+import java.util.function.Predicate;
 import java.util.regex.Pattern;
 
 import static java.util.Collections.singleton;
@@ -114,6 +118,54 @@ public class SubscriptionStateTest {
         assertEquals(0, state.numAssignedPartitions());
     }
 
+    @Test
+    public void testIsFetchableOnManualAssignment() {
+        state.assignFromUser(Set.of(tp0, tp1));
+        assertAssignedPartitionIsFetchable();
+    }
+
+    @Test
+    public void testIsFetchableOnAutoAssignment() {
+        state.subscribe(Set.of(topic), Optional.of(rebalanceListener));
+        state.assignFromSubscribed(Set.of(tp0, tp1));
+        assertAssignedPartitionIsFetchable();
+    }
+
+    private void assertAssignedPartitionIsFetchable() {
+        assertEquals(2, state.assignedPartitions().size());
+        assertTrue(state.assignedPartitions().contains(tp0));
+        assertTrue(state.assignedPartitions().contains(tp1));
+
+        assertFalse(state.isFetchable(tp0), "Should not be fetchable without a valid position");
+        assertFalse(state.isFetchable(tp1), "Should not be fetchable without a valid position");
+
+        state.seek(tp0, 1);
+        state.seek(tp1, 1);
+
+        assertTrue(state.isFetchable(tp0));
+        assertTrue(state.isFetchable(tp1));
+    }
+
+    @Test
+    public void testIsFetchableConsidersExplicitTopicSubscription() {
+        state.subscribe(Set.of(topic1), Optional.of(rebalanceListener));
+        state.assignFromSubscribed(Set.of(t1p0));
+        state.seek(t1p0, 1);
+
+        assertEquals(Set.of(t1p0), state.assignedPartitions());
+        assertTrue(state.isFetchable(t1p0));
+
+        // Change subscription. Assigned partitions should remain unchanged but not fetchable.
+        state.subscribe(Set.of(topic), Optional.of(rebalanceListener));
+        assertEquals(Set.of(t1p0), state.assignedPartitions());
+        assertFalse(state.isFetchable(t1p0), "Assigned partitions not in the subscription should not be fetchable");
+
+        // Unsubscribe. Assigned partitions should be cleared and not fetchable.
+        state.unsubscribe();
+        assertTrue(state.assignedPartitions().isEmpty());
+        assertFalse(state.isFetchable(t1p0));
+    }
+
     @Test
     public void testGroupSubscribe() {
         state.subscribe(singleton(topic1), Optional.of(rebalanceListener));
@@ -273,6 +325,7 @@ public class SubscriptionStateTest {
         state.subscribe(singleton(topic), Optional.of(rebalanceListener));
         state.assignFromSubscribedAwaitingCallback(singleton(tp0), singleton(tp0));
         assertAssignmentAppliedAwaitingCallback(tp0);
+        assertEquals(singleton(tp0.topic()), state.subscription());
 
         // Simulate callback setting position to start fetching from
         state.seek(tp0, 100);
@@ -292,6 +345,7 @@ public class SubscriptionStateTest {
         state.subscribe(singleton(topic), Optional.of(rebalanceListener));
         state.assignFromSubscribedAwaitingCallback(singleton(tp0), singleton(tp0));
         assertAssignmentAppliedAwaitingCallback(tp0);
+        assertEquals(singleton(tp0.topic()), state.subscription());
 
         // Callback completed (without updating positions). Partition should require initializing
         // positions, and start fetching once a valid position is set.
@@ -309,6 +363,7 @@ public class SubscriptionStateTest {
         state.subscribe(singleton(topic), Optional.of(rebalanceListener));
         state.assignFromSubscribedAwaitingCallback(singleton(tp0), singleton(tp0));
         assertAssignmentAppliedAwaitingCallback(tp0);
+        assertEquals(singleton(tp0.topic()), state.subscription());
         state.enablePartitionsAwaitingCallback(singleton(tp0));
         state.seek(tp0, 100);
         assertTrue(state.isFetchable(tp0));
@@ -331,7 +386,6 @@ public class SubscriptionStateTest {
     private void assertAssignmentAppliedAwaitingCallback(TopicPartition topicPartition) {
         assertEquals(singleton(topicPartition), state.assignedPartitions());
         assertEquals(1, state.numAssignedPartitions());
-        assertEquals(singleton(topicPartition.topic()), state.subscription());
 
         assertFalse(state.isFetchable(topicPartition));
         assertEquals(1, state.initializingPartitions().size());
@@ -404,6 +458,75 @@ public class SubscriptionStateTest {
         state.subscribe(new SubscriptionPattern(pattern), Optional.of(rebalanceListener));
         assertTrue(state.toString().contains("type=AUTO_PATTERN_RE2J"));
         assertTrue(state.toString().contains("subscribedPattern=" + pattern));
+        assertTrue(state.assignedTopicIds().isEmpty());
+    }
+
+    @Test
+    public void testIsAssignedFromRe2j() {
+        assertFalse(state.isAssignedFromRe2j(null));
+        Uuid assignedUuid = Uuid.randomUuid();
+        assertFalse(state.isAssignedFromRe2j(assignedUuid));
+
+        state.subscribe(new SubscriptionPattern("foo.*"), Optional.empty());
+        assertTrue(state.hasRe2JPatternSubscription());
+        assertFalse(state.isAssignedFromRe2j(assignedUuid));
+
+        state.setAssignedTopicIds(Set.of(assignedUuid));
+        assertTrue(state.isAssignedFromRe2j(assignedUuid));
+
+        state.unsubscribe();
+        assertFalse(state.isAssignedFromRe2j(assignedUuid));
+        assertFalse(state.hasRe2JPatternSubscription());
+
+    }
+
+    @Test
+    public void testAssignedPartitionsWithTopicIdsForRe2Pattern() {
+        state.subscribe(new SubscriptionPattern("t.*"), Optional.of(rebalanceListener));
+        assertTrue(state.assignedTopicIds().isEmpty());
+
+        TopicIdPartitionSet reconciledAssignmentFromRegex = new TopicIdPartitionSet();
+        reconciledAssignmentFromRegex.addAll(Uuid.randomUuid(), topic, Set.of(0));
+        state.assignFromSubscribedAwaitingCallback(singleton(tp0), singleton(tp0));
+        assertAssignmentAppliedAwaitingCallback(tp0);
+
+        // Simulate callback setting position to start fetching from
+        state.seek(tp0, 100);
+
+        // Callback completed. Partition should be fetchable, from the position previously defined
+        state.enablePartitionsAwaitingCallback(singleton(tp0));
+        assertEquals(0, state.initializingPartitions().size());
+        assertTrue(state.isFetchable(tp0));
+        assertTrue(state.hasAllFetchPositions());
+        assertEquals(100L, state.position(tp0).offset);
+    }
+
+    @Test
+    public void testAssignedTopicIdsPreservedWhenReconciliationCompletes() {
+        state.subscribe(new SubscriptionPattern("t.*"), Optional.of(rebalanceListener));
+        assertTrue(state.assignedTopicIds().isEmpty());
+
+        // First assignment received from coordinator
+        Uuid firstAssignedUuid = Uuid.randomUuid();
+        state.setAssignedTopicIds(Set.of(firstAssignedUuid));
+
+        // Second assignment received from coordinator (while the 1st still be reconciling)
+        Uuid secondAssignedUuid = Uuid.randomUuid();
+        state.setAssignedTopicIds(Set.of(firstAssignedUuid, secondAssignedUuid));
+
+        // First reconciliation completes and updates the subscription state
+        state.assignFromSubscribedAwaitingCallback(singleton(tp0), singleton(tp0));
+
+        // First assignment should have been applied
+        assertAssignmentAppliedAwaitingCallback(tp0);
+
+        // Assigned topic IDs should still have both topics (one reconciled, one not reconciled yet)
+        assertEquals(
+                Set.of(firstAssignedUuid, secondAssignedUuid),
+                state.assignedTopicIds(),
+                "Updating the subscription state when a reconciliation completes " +
+                        "should not overwrite assigned topics that have not been reconciled yet"
+        );
     }
 
     @Test
@@ -1001,4 +1124,33 @@ public class SubscriptionStateTest {
 
         assertThrows(IllegalStateException.class, () -> state.isOffsetResetNeeded(unassignedPartition));
     }
+
+    // This test ensures the "fetchablePartitions" does not run the custom predicate if the partition is not fetchable
+    // This func is used in the hot path for fetching, to find fetchable partitions that are not in the buffer,
+    // so it should avoid evaluating the predicate if not needed.
+    @Test
+    public void testFetchablePartitionsPerformsCheapChecksFirst() {
+        // Setup fetchable partition and pause it
+        state.assignFromUser(Set.of(tp0));
+        state.seek(tp0, 100);
+        assertTrue(state.isFetchable(tp0));
+        state.pause(tp0);
+
+        // Retrieve fetchable partitions with custom predicate.
+        AtomicBoolean predicateEvaluated = new AtomicBoolean(false);
+        Predicate<TopicPartition> isBuffered = tp -> {
+            predicateEvaluated.set(true);
+            return true;
+        };
+        List<TopicPartition> fetchablePartitions = state.fetchablePartitions(isBuffered);
+        assertTrue(fetchablePartitions.isEmpty());
+        assertFalse(predicateEvaluated.get(), "Custom predicate should not be evaluated when partitions are not fetchable");
+
+        // Resume partition and retrieve fetchable again
+        state.resume(tp0);
+        predicateEvaluated.set(false);
+        fetchablePartitions = state.fetchablePartitions(isBuffered);
+        assertTrue(predicateEvaluated.get());
+        assertEquals(tp0, fetchablePartitions.get(0));
+    }
 }
