@@ -114,6 +114,13 @@ public class AbstractConfigTest {
         assertEquals(expected, originalsWithPrefix);
     }
 
+    @Test
+    public void testPreprocessConfig() {
+        Properties props = new Properties();
+        TestConfig config = new TestConfig(props);
+        assertEquals("success", config.get("preprocess"));
+    }
+
     @Test
     public void testValuesWithPrefixOverride() {
         String prefix = "prefix.";
@@ -702,17 +709,32 @@ public class AbstractConfigTest {
 
         public static final String METRIC_REPORTER_CLASSES_CONFIG = "metric.reporters";
         private static final String METRIC_REPORTER_CLASSES_DOC = "A list of classes to use as metrics reporters.";
+        public static final String PREPROCESSOR_CONFIG = "preprocess";
+        private static final String PREPROCESSOR_CONFIG_DOC = "Override from preprocess step.";
+
         static {
             CONFIG = new ConfigDef().define(METRIC_REPORTER_CLASSES_CONFIG,
                                             Type.LIST,
                                             "",
                                             Importance.LOW,
-                                            METRIC_REPORTER_CLASSES_DOC);
+                                            METRIC_REPORTER_CLASSES_DOC)
+                                    .define(PREPROCESSOR_CONFIG,
+                                            Type.STRING,
+                                            "",
+                                            Importance.LOW,
+                                            PREPROCESSOR_CONFIG_DOC);
         }
 
         public TestConfig(Map<?, ?> props) {
             super(CONFIG, props);
         }
+
+        @Override
+        protected Map<String, Object> preProcessParsedConfig(Map<String, Object> parsedValues) {
+            Map<String, Object> ret = new HashMap<>(parsedValues);
+            ret.put("preprocess", "success");
+            return ret;
+        }
     }
 
     public static class ConfiguredFakeMetricsReporter extends FakeMetricsReporter {
