@@ -16,8 +16,9 @@
  */
 package org.apache.kafka.common.security.auth;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
+
+import static org.junit.jupiter.api.Assertions.assertEquals;
 
 public class KafkaPrincipalTest {
 
@@ -27,7 +28,7 @@ public class KafkaPrincipalTest {
         KafkaPrincipal principal1 = new KafkaPrincipal(KafkaPrincipal.USER_TYPE, name);
         KafkaPrincipal principal2 = new KafkaPrincipal(KafkaPrincipal.USER_TYPE, name);
 
-        Assert.assertEquals(principal1.hashCode(), principal2.hashCode());
-        Assert.assertEquals(principal1, principal2);
+        assertEquals(principal1.hashCode(), principal2.hashCode());
+        assertEquals(principal1, principal2);
     }
 }
