@@ -16,16 +16,15 @@
  */
 package org.apache.kafka.common.security.oauthbearer;
 
+import org.apache.kafka.common.internals.SecurityManagerCompatibility;
 import org.apache.kafka.common.security.oauthbearer.internals.OAuthBearerSaslClientCallbackHandler;
 
 import org.junit.jupiter.api.Test;
 
 import java.io.IOException;
-import java.security.AccessController;
-import java.security.PrivilegedActionException;
-import java.security.PrivilegedExceptionAction;
 import java.util.Collections;
 import java.util.Set;
+import java.util.concurrent.CompletionException;
 
 import javax.security.auth.Subject;
 import javax.security.auth.callback.Callback;
@@ -66,8 +65,8 @@ public class OAuthBearerSaslClientCallbackHandlerTest {
     @Test
     public void testWithZeroTokens() {
         OAuthBearerSaslClientCallbackHandler handler = createCallbackHandler();
-        PrivilegedActionException e = assertThrows(PrivilegedActionException.class, () -> Subject.doAs(new Subject(),
-            (PrivilegedExceptionAction<Void>) () -> {
+        CompletionException e = assertThrows(CompletionException.class, () -> SecurityManagerCompatibility.get().callAs(new Subject(),
+            () -> {
                 OAuthBearerTokenCallback callback = new OAuthBearerTokenCallback();
                 handler.handle(new Callback[] {callback});
                 return null;
@@ -77,11 +76,11 @@ public class OAuthBearerSaslClientCallbackHandlerTest {
     }
 
     @Test()
-    public void testWithPotentiallyMultipleTokens() throws Exception {
+    public void testWithPotentiallyMultipleTokens() {
         OAuthBearerSaslClientCallbackHandler handler = createCallbackHandler();
-        Subject.doAs(new Subject(), (PrivilegedExceptionAction<Void>) () -> {
+        SecurityManagerCompatibility.get().callAs(new Subject(), () -> {
             final int maxTokens = 4;
-            final Set<Object> privateCredentials = Subject.getSubject(AccessController.getContext())
+            final Set<Object> privateCredentials = SecurityManagerCompatibility.get().current()
                     .getPrivateCredentials();
             privateCredentials.clear();
             for (int num = 1; num <= maxTokens; ++num) {
