@@ -359,7 +359,6 @@ public abstract class SslFactoryTest {
         sslConfig = new TestSecurityConfig(props);
         sslFactory.reconfigure(sslConfig.values());
         assertNotSame(sslEngineFactory, sslFactory.sslEngineFactory(), "SslEngineFactory not recreated");
-        sslEngineFactory = sslFactory.sslEngineFactory();
     }
 
     @Test
@@ -400,15 +399,15 @@ public abstract class SslFactoryTest {
 
     @Test
     public void testKeystoreVerifiableUsingTruststore() throws Exception {
-        verifyKeystoreVerifiableUsingTruststore(false, tlsProtocol);
+        verifyKeystoreVerifiableUsingTruststore(false);
     }
 
     @Test
     public void testPemKeystoreVerifiableUsingTruststore() throws Exception {
-        verifyKeystoreVerifiableUsingTruststore(true, tlsProtocol);
+        verifyKeystoreVerifiableUsingTruststore(true);
     }
 
-    private void verifyKeystoreVerifiableUsingTruststore(boolean usePem, String tlsProtocol) throws Exception {
+    private void verifyKeystoreVerifiableUsingTruststore(boolean usePem) throws Exception {
         File trustStoreFile1 = usePem ? null : TestUtils.tempFile("truststore1", ".jks");
         Map<String, Object> sslConfig1 = sslConfigsBuilder(ConnectionMode.SERVER)
                 .createNewTrustStore(trustStoreFile1)
@@ -436,15 +435,15 @@ public abstract class SslFactoryTest {
 
     @Test
     public void testCertificateEntriesValidation() throws Exception {
-        verifyCertificateEntriesValidation(false, tlsProtocol);
+        verifyCertificateEntriesValidation(false);
     }
 
     @Test
     public void testPemCertificateEntriesValidation() throws Exception {
-        verifyCertificateEntriesValidation(true, tlsProtocol);
+        verifyCertificateEntriesValidation(true);
     }
 
-    private void verifyCertificateEntriesValidation(boolean usePem, String tlsProtocol) throws Exception {
+    private void verifyCertificateEntriesValidation(boolean usePem) throws Exception {
         File trustStoreFile = usePem ? null : TestUtils.tempFile("truststore", ".jks");
         Map<String, Object> serverSslConfig = sslConfigsBuilder(ConnectionMode.SERVER)
                 .createNewTrustStore(trustStoreFile)
