@@ -20,7 +20,6 @@ import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 
@@ -69,37 +68,4 @@ public class JavaTest {
                 : "com.sun.security.auth.module.Krb5LoginModule";
         Class.forName(clazz);
     }
-
-    @Test
-    public void testJavaVersion() {
-        Java.Version v = Java.parseVersion("9");
-        assertEquals(9, v.majorVersion);
-        assertEquals(0, v.minorVersion);
-        assertTrue(v.isJava9Compatible());
-
-        v = Java.parseVersion("9.0.1");
-        assertEquals(9, v.majorVersion);
-        assertEquals(0, v.minorVersion);
-        assertTrue(v.isJava9Compatible());
-
-        v = Java.parseVersion("9.0.0.15"); // Azul Zulu
-        assertEquals(9, v.majorVersion);
-        assertEquals(0, v.minorVersion);
-        assertTrue(v.isJava9Compatible());
-
-        v = Java.parseVersion("9.1");
-        assertEquals(9, v.majorVersion);
-        assertEquals(1, v.minorVersion);
-        assertTrue(v.isJava9Compatible());
-
-        v = Java.parseVersion("1.8.0_152");
-        assertEquals(1, v.majorVersion);
-        assertEquals(8, v.minorVersion);
-        assertFalse(v.isJava9Compatible());
-
-        v = Java.parseVersion("1.7.0_80");
-        assertEquals(1, v.majorVersion);
-        assertEquals(7, v.minorVersion);
-        assertFalse(v.isJava9Compatible());
-    }
 }
