@@ -111,7 +111,7 @@ public class TestSslUtils {
      * @param dn the X.509 Distinguished Name, eg "CN=Test, L=London, C=GB"
      * @param pair the KeyPair
      * @param days how many days from now the Certificate is valid for, or - for negative values - how many days before now
-     * @param algorithm the signing algorithm, eg "SHA256withRSA"
+     * @param algorithm the signing algorithm, eg "SHA1withRSA"
      * @return the self-signed certificate
      * @throws CertificateException thrown if a security error or an IO error occurred.
      */
@@ -132,7 +132,7 @@ public class TestSslUtils {
      *        CA.
      * @param parentKeyPair The key pair of the issuer. Leave null if you want to generate a root
      *        CA.
-     * @param algorithm the signing algorithm, eg "SHA256withRSA"
+     * @param algorithm the signing algorithm, eg "SHA1withRSA"
      * @return the signed certificate
      * @throws CertificateException
      */
@@ -372,7 +372,7 @@ public class TestSslUtils {
         try (PemWriter pemWriter = new PemWriter(new OutputStreamWriter(out, StandardCharsets.UTF_8))) {
             pemWriter.writeObject(new JcaMiscPEMGenerator(cert));
         }
-        return new String(out.toByteArray(), StandardCharsets.UTF_8);
+        return out.toString(StandardCharsets.UTF_8);
     }
 
     static String pem(PrivateKey privateKey, Password password) throws IOException {
@@ -390,7 +390,7 @@ public class TestSslUtils {
                 }
             }
         }
-        return new String(out.toByteArray(), StandardCharsets.UTF_8);
+        return out.toString(StandardCharsets.UTF_8);
     }
 
     public static class CertificateBuilder {
@@ -399,7 +399,7 @@ public class TestSslUtils {
         private byte[] subjectAltName;
 
         public CertificateBuilder() {
-            this(30, "SHA256withRSA");
+            this(30, "SHA1withRSA");
         }
 
         public CertificateBuilder(int days, String algorithm) {
