@@ -213,11 +213,15 @@ public class ConnectSchema implements Schema {
         validateValue(null, schema, value);
     }
 
-    public static void validateValue(String name, Schema schema, Object value) {
+    public static void validateValue(String field, Schema schema, Object value) {
+        validateValue(schema, value, field == null ? "value" : "field: \"" + field + "\"");
+    }
+
+    private static void validateValue(Schema schema, Object value, String location) {
         if (value == null) {
             if (!schema.isOptional())
-                throw new DataException("Invalid value: null used for required field: \"" + name
-                        + "\", schema type: " + schema.type());
+                throw new DataException("Invalid value: null used for required " + location
+                        + ", schema type: " + schema.type());
             return;
         }
 
@@ -236,8 +240,8 @@ public class ConnectSchema implements Schema {
                 exceptionMessage.append(" \"").append(schema.name()).append("\"");
             }
             exceptionMessage.append(" with type ").append(schema.type()).append(": ").append(value.getClass());
-            if (name != null) {
-                exceptionMessage.append(" for field: \"").append(name).append("\"");
+            if (location != null) {
+                exceptionMessage.append(" for ").append(location);
             }
             throw new DataException(exceptionMessage.toString());
         }
@@ -251,19 +255,33 @@ public class ConnectSchema implements Schema {
                 break;
             case ARRAY:
                 List<?> array = (List<?>) value;
-                for (Object entry : array)
-                    validateValue(schema.valueSchema(), entry);
+                String entryLocation = "element of array " + location;
+                Schema arrayValueSchema = assertSchemaNotNull(schema.valueSchema(), entryLocation);
+                for (Object entry : array) {
+                    validateValue(arrayValueSchema, entry, entryLocation);
+                }
                 break;
             case MAP:
                 Map<?, ?> map = (Map<?, ?>) value;
+                String keyLocation = "key of map " + location;
+                String valueLocation = "value of map " + location;
+                Schema mapKeySchema = assertSchemaNotNull(schema.keySchema(), keyLocation);
+                Schema mapValueSchema = assertSchemaNotNull(schema.valueSchema(), valueLocation);
                 for (Map.Entry<?, ?> entry : map.entrySet()) {
-                    validateValue(schema.keySchema(), entry.getKey());
-                    validateValue(schema.valueSchema(), entry.getValue());
+                    validateValue(mapKeySchema, entry.getKey(), keyLocation);
+                    validateValue(mapValueSchema, entry.getValue(), valueLocation);
                 }
                 break;
         }
     }
 
+    private static Schema assertSchemaNotNull(Schema schema, String location) {
+        if (schema == null) {
+            throw new DataException("No schema defined for " + location);
+        }
+        return schema;
+    }
+
     private static List<Class<?>> expectedClassesFor(Schema schema) {
         List<Class<?>> expectedClasses = LOGICAL_TYPE_CLASSES.get(schema.name());
         if (expectedClasses == null)
