@@ -20,6 +20,7 @@ import org.apache.kafka.clients.producer.Producer;
 import org.apache.kafka.clients.producer.ProducerRecord;
 import org.apache.kafka.clients.producer.RecordMetadata;
 import org.apache.kafka.common.errors.InvalidProducerEpochException;
+import org.apache.kafka.common.internals.Plugin;
 import org.apache.kafka.common.metrics.Sensor;
 import org.apache.kafka.common.metrics.stats.Avg;
 import org.apache.kafka.common.metrics.stats.Max;
@@ -31,6 +32,7 @@ import org.apache.kafka.connect.runtime.errors.ErrorHandlingMetrics;
 import org.apache.kafka.connect.runtime.errors.ErrorReporter;
 import org.apache.kafka.connect.runtime.errors.ProcessingContext;
 import org.apache.kafka.connect.runtime.errors.RetryWithToleranceOperator;
+import org.apache.kafka.connect.runtime.isolation.LoaderSwap;
 import org.apache.kafka.connect.source.SourceRecord;
 import org.apache.kafka.connect.source.SourceTask;
 import org.apache.kafka.connect.source.SourceTask.TransactionBoundary;
@@ -56,6 +58,7 @@ import java.util.Objects;
 import java.util.Optional;
 import java.util.concurrent.Executor;
 import java.util.concurrent.atomic.AtomicReference;
+import java.util.function.Function;
 import java.util.function.Supplier;
 
 
@@ -78,9 +81,9 @@ class ExactlyOnceWorkerSourceTask extends AbstractWorkerSourceTask {
                                        SourceTask task,
                                        TaskStatus.Listener statusListener,
                                        TargetState initialState,
-                                       Converter keyConverter,
-                                       Converter valueConverter,
-                                       HeaderConverter headerConverter,
+                                       Plugin<Converter> keyConverterPlugin,
+                                       Plugin<Converter> valueConverterPlugin,
+                                       Plugin<HeaderConverter> headerConverterPlugin,
                                        TransformationChain<SourceRecord, SourceRecord> transformationChain,
                                        Producer<byte[], byte[]> producer,
                                        TopicAdmin admin,
@@ -100,11 +103,13 @@ class ExactlyOnceWorkerSourceTask extends AbstractWorkerSourceTask {
                                        Executor closeExecutor,
                                        Runnable preProducerCheck,
                                        Runnable postProducerCheck,
-                                       Supplier<List<ErrorReporter<SourceRecord>>> errorReportersSupplier) {
-        super(id, task, statusListener, initialState, keyConverter, valueConverter, headerConverter, transformationChain,
-                new WorkerSourceTaskContext(offsetReader, id, configState, buildTransactionContext(sourceConfig)),
+                                       Supplier<List<ErrorReporter<SourceRecord>>> errorReportersSupplier,
+                                       TaskPluginsMetadata pluginsMetadata,
+                                       Function<ClassLoader, LoaderSwap> pluginLoaderSwapper) {
+        super(id, task, statusListener, initialState, configState, keyConverterPlugin, valueConverterPlugin, headerConverterPlugin, transformationChain,
+                buildTransactionContext(sourceConfig),
                 producer, admin, topicGroups, offsetReader, offsetWriter, offsetStore, workerConfig, connectMetrics, errorMetrics,
-                loader, time, retryWithToleranceOperator, statusBackingStore, closeExecutor, errorReportersSupplier);
+                loader, time, retryWithToleranceOperator, statusBackingStore, closeExecutor, errorReportersSupplier, pluginsMetadata, pluginLoaderSwapper);
 
         this.transactionOpen = false;
         this.committableRecords = new LinkedHashMap<>();
@@ -424,24 +429,22 @@ class ExactlyOnceWorkerSourceTask extends AbstractWorkerSourceTask {
             SourceConnectorConfig sourceConfig,
             WorkerTransactionContext transactionContext) {
         TransactionBoundary boundary = sourceConfig.transactionBoundary();
-        switch (boundary) {
-            case POLL:
-                return new TransactionBoundaryManager() {
-                    @Override
-                    protected boolean shouldCommitTransactionForBatch(long currentTimeMs) {
-                        return true;
-                    }
+        return switch (boundary) {
+            case POLL -> new TransactionBoundaryManager() {
+                @Override
+                protected boolean shouldCommitTransactionForBatch(long currentTimeMs) {
+                    return true;
+                }
 
-                    @Override
-                    protected boolean shouldCommitFinalTransaction() {
-                        return true;
-                    }
-                };
-
-            case INTERVAL:
+                @Override
+                protected boolean shouldCommitFinalTransaction() {
+                    return true;
+                }
+            };
+            case INTERVAL -> {
                 long transactionBoundaryInterval = Optional.ofNullable(sourceConfig.transactionBoundaryInterval())
                         .orElse(workerConfig.offsetCommitInterval());
-                return new TransactionBoundaryManager() {
+                yield new TransactionBoundaryManager() {
                     private final long commitInterval = transactionBoundaryInterval;
                     private long lastCommit;
 
@@ -461,14 +464,14 @@ class ExactlyOnceWorkerSourceTask extends AbstractWorkerSourceTask {
                     }
 
                     @Override
-                    protected  boolean shouldCommitFinalTransaction() {
+                    protected boolean shouldCommitFinalTransaction() {
                         return true;
                     }
                 };
-
-            case CONNECTOR:
+            }
+            case CONNECTOR -> {
                 Objects.requireNonNull(transactionContext, "Transaction context must be provided when using connector-defined transaction boundaries");
-                return new TransactionBoundaryManager() {
+                yield new TransactionBoundaryManager() {
                     @Override
                     protected boolean shouldCommitFinalTransaction() {
                         return shouldCommitTransactionForBatch(time.milliseconds());
@@ -509,9 +512,8 @@ class ExactlyOnceWorkerSourceTask extends AbstractWorkerSourceTask {
                         transactionOpen = false;
                     }
                 };
-            default:
-                throw new IllegalArgumentException("Unrecognized transaction boundary: " + boundary);
-        }
+            }
+        };
     }
 
     TransactionMetricsGroup transactionMetricsGroup() {
