@@ -227,81 +227,33 @@ class SubmittedRecords {
     /**
      * Contains a snapshot of offsets that can be committed for a source task and metadata for that offset commit
      * (such as the number of messages for which offsets can and cannot be committed).
+     * @param offsets the offsets that can be committed at the time of the snapshot
+     * @param numCommittableMessages the number of committable messages at the time of the snapshot, where a
+     *                               committable message is both acknowledged and not preceded by any unacknowledged
+     *                               messages in the deque for its source partition
+     * @param numUncommittableMessages the number of uncommittable messages at the time of the snapshot, where an
+     *                                 uncommittable message is either unacknowledged, or preceded in the deque for its
+     *                                 source partition by an unacknowledged message
+     * @param numDeques the number of non-empty deques tracking uncommittable messages at the time of the snapshot
+     * @param largestDequeSize the size of the largest deque at the time of the snapshot
+     * @param largestDequePartition the applicable partition, which may be null, or null if there are no uncommitted
+     *                              messages; it is the caller's responsibility to distinguish between these two cases
+     *                              via {@link #hasPending()}
      */
-    static class CommittableOffsets {
+    record CommittableOffsets(Map<Map<String, Object>, Map<String, Object>> offsets,
+                              int numCommittableMessages,
+                              int numUncommittableMessages,
+                              int numDeques,
+                              int largestDequeSize,
+                              Map<String, Object> largestDequePartition) {
 
         /**
          * An "empty" snapshot that contains no offsets to commit and whose metadata contains no committable or uncommitable messages.
          */
         public static final CommittableOffsets EMPTY = new CommittableOffsets(Collections.emptyMap(), 0, 0, 0, 0, null);
 
-        private final Map<Map<String, Object>, Map<String, Object>> offsets;
-        private final int numCommittableMessages;
-        private final int numUncommittableMessages;
-        private final int numDeques;
-        private final int largestDequeSize;
-        private final Map<String, Object> largestDequePartition;
-
-        CommittableOffsets(
-                Map<Map<String, Object>, Map<String, Object>> offsets,
-                int numCommittableMessages,
-                int numUncommittableMessages,
-                int numDeques,
-                int largestDequeSize,
-                Map<String, Object> largestDequePartition
-        ) {
-            this.offsets = offsets != null ? new HashMap<>(offsets) : Collections.emptyMap();
-            this.numCommittableMessages = numCommittableMessages;
-            this.numUncommittableMessages = numUncommittableMessages;
-            this.numDeques = numDeques;
-            this.largestDequeSize = largestDequeSize;
-            this.largestDequePartition = largestDequePartition;
-        }
-
-        /**
-         * @return the offsets that can be committed at the time of the snapshot
-         */
-        public Map<Map<String, Object>, Map<String, Object>> offsets() {
-            return Collections.unmodifiableMap(offsets);
-        }
-
-        /**
-         * @return the number of committable messages at the time of the snapshot, where a committable message is both
-         * acknowledged and not preceded by any unacknowledged messages in the deque for its source partition
-         */
-        public int numCommittableMessages() {
-            return numCommittableMessages;
-        }
-
-        /**
-         * @return the number of uncommittable messages at the time of the snapshot, where an uncommittable message
-         * is either unacknowledged, or preceded in the deque for its source partition by an unacknowledged message
-         */
-        public int numUncommittableMessages() {
-            return numUncommittableMessages;
-        }
-
-        /**
-         * @return the number of non-empty deques tracking uncommittable messages at the time of the snapshot
-         */
-        public int numDeques() {
-            return numDeques;
-        }
-
-        /**
-         * @return the size of the largest deque at the time of the snapshot
-         */
-        public int largestDequeSize() {
-            return largestDequeSize;
-        }
-
-        /**
-         * Get the partition for the deque with the most uncommitted messages at the time of the snapshot.
-         * @return the applicable partition, which may be null, or null if there are no uncommitted messages;
-         * it is the caller's responsibility to distinguish between these two cases via {@link #hasPending()}
-         */
-        public Map<String, Object> largestDequePartition() {
-            return largestDequePartition;
+        CommittableOffsets {
+            offsets = Collections.unmodifiableMap(offsets);
         }
 
         /**
@@ -323,6 +275,7 @@ class SubmittedRecords {
          * Offsets are combined (giving precedence to the newer snapshot in case of conflict), the total number of
          * committable messages is summed across the two snapshots, and the newer snapshot's information on pending
          * messages (num deques, largest deque size, etc.) is used.
+         *
          * @param newerOffsets the newer snapshot to combine with this snapshot
          * @return the new offset snapshot containing information from this snapshot and the newer snapshot; never null
          */
