@@ -17,6 +17,7 @@
 package org.apache.kafka.connect.runtime.distributed;
 
 import org.apache.kafka.clients.GroupRebalanceConfig;
+import org.apache.kafka.clients.consumer.CloseOptions;
 import org.apache.kafka.clients.consumer.internals.AbstractCoordinator;
 import org.apache.kafka.clients.consumer.internals.ConsumerNetworkClient;
 import org.apache.kafka.common.metrics.Measurable;
@@ -183,16 +184,11 @@ public class WorkerCoordinator extends AbstractCoordinator implements Closeable
         configSnapshot = configStorage.snapshot();
         final ExtendedAssignment localAssignmentSnapshot = assignmentSnapshot;
         ExtendedWorkerState workerState = new ExtendedWorkerState(restUrl, configSnapshot.offset(), localAssignmentSnapshot);
-        switch (protocolCompatibility) {
-            case EAGER:
-                return ConnectProtocol.metadataRequest(workerState);
-            case COMPATIBLE:
-                return IncrementalCooperativeConnectProtocol.metadataRequest(workerState, false);
-            case SESSIONED:
-                return IncrementalCooperativeConnectProtocol.metadataRequest(workerState, true);
-            default:
-                throw new IllegalStateException("Unknown Connect protocol compatibility mode " + protocolCompatibility);
-        }
+        return switch (protocolCompatibility) {
+            case EAGER -> ConnectProtocol.metadataRequest(workerState);
+            case COMPATIBLE -> IncrementalCooperativeConnectProtocol.metadataRequest(workerState, false);
+            case SESSIONED -> IncrementalCooperativeConnectProtocol.metadataRequest(workerState, true);
+        };
     }
 
     @Override
@@ -271,7 +267,7 @@ public class WorkerCoordinator extends AbstractCoordinator implements Closeable
     @Override
     protected void handlePollTimeoutExpiry() {
         listener.onPollTimeoutExpiry();
-        maybeLeaveGroup("worker poll timeout has expired.");
+        maybeLeaveGroup(CloseOptions.GroupMembershipOperation.DEFAULT, "worker poll timeout has expired.");
     }
 
     /**
@@ -440,8 +436,7 @@ public class WorkerCoordinator extends AbstractCoordinator implements Closeable
         @Override
         public boolean equals(Object o) {
             if (this == o) return true;
-            if (!(o instanceof LeaderState)) return false;
-            LeaderState that = (LeaderState) o;
+            if (!(o instanceof LeaderState that)) return false;
             return Objects.equals(allMembers, that.allMembers)
                     && Objects.equals(connectorOwners, that.connectorOwners)
                     && Objects.equals(taskOwners, that.taskOwners);
@@ -644,10 +639,9 @@ public class WorkerCoordinator extends AbstractCoordinator implements Closeable
             if (this == o) {
                 return true;
             }
-            if (!(o instanceof WorkerLoad)) {
+            if (!(o instanceof WorkerLoad that)) {
                 return false;
             }
-            WorkerLoad that = (WorkerLoad) o;
             return worker.equals(that.worker) &&
                     connectors.equals(that.connectors) &&
                     tasks.equals(that.tasks);
