@@ -16,6 +16,8 @@
  */
 package org.apache.kafka.connect.runtime.isolation;
 
+import org.apache.maven.artifact.versioning.InvalidVersionSpecificationException;
+import org.apache.maven.artifact.versioning.VersionRange;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -408,13 +410,10 @@ public class PluginUtils {
      */
     public static String prunedName(PluginDesc<?> plugin) {
         // It's currently simpler to switch on type than do pattern matching.
-        switch (plugin.type()) {
-            case SOURCE:
-            case SINK:
-                return prunePluginName(plugin, "Connector");
-            default:
-                return prunePluginName(plugin, plugin.type().simpleName());
-        }
+        return switch (plugin.type()) {
+            case SOURCE, SINK -> prunePluginName(plugin, "Connector");
+            default -> prunePluginName(plugin, plugin.type().simpleName());
+        };
     }
 
     private static String prunePluginName(PluginDesc<?> plugin, String suffix) {
@@ -469,7 +468,7 @@ public class PluginUtils {
         }
         return distinctUrls(urls);
     }
-    
+
     private static Collection<URL> forClassLoader(ClassLoader classLoader) {
         final Collection<URL> result = new ArrayList<>();
         while (classLoader != null) {
@@ -483,7 +482,7 @@ public class PluginUtils {
         }
         return distinctUrls(result);
     }
-    
+
     private static Collection<URL> distinctUrls(Collection<URL> urls) {
         Map<String, URL> distinct = new HashMap<>(urls.size());
         for (URL url : urls) {
@@ -491,4 +490,21 @@ public class PluginUtils {
         }
         return distinct.values();
     }
+
+    public static VersionRange connectorVersionRequirement(String version) throws InvalidVersionSpecificationException {
+        if (version == null || version.equals("latest")) {
+            return null;
+        }
+        version = version.trim();
+
+        // check first if the given version is valid
+        VersionRange range = VersionRange.createFromVersionSpec(version);
+
+        if (range.hasRestrictions()) {
+            return range;
+        }
+        // now if the version is not enclosed we consider it as a hard requirement and enclose it in []
+        version = "[" + version + "]";
+        return VersionRange.createFromVersionSpec(version);
+    }
 }
