@@ -92,7 +92,7 @@ public class RestExtensionIntegrationTest {
         try {
             // setup up props for the connector
             Map<String, String> connectorProps = new HashMap<>();
-            connectorProps.put(CONNECTOR_CLASS_CONFIG, MonitorableSinkConnector.class.getSimpleName());
+            connectorProps.put(CONNECTOR_CLASS_CONFIG, TestableSinkConnector.class.getSimpleName());
             connectorProps.put(TASKS_MAX_CONFIG, String.valueOf(1));
             connectorProps.put(TOPICS_CONFIG, "test-topic");
 
