@@ -35,17 +35,15 @@ public class RestartPlanTest {
     @Test
     public void testRestartPlan() {
         ConnectorStateInfo.ConnectorState state = new ConnectorStateInfo.ConnectorState(
-                AbstractStatus.State.RESTARTING.name(),
-                "foo",
-                null
+                AbstractStatus.State.RESTARTING.name(), "foo", null, null
         );
         List<TaskState> tasks = new ArrayList<>();
-        tasks.add(new TaskState(1, AbstractStatus.State.RUNNING.name(), "worker1", null));
-        tasks.add(new TaskState(2, AbstractStatus.State.PAUSED.name(), "worker1", null));
-        tasks.add(new TaskState(3, AbstractStatus.State.RESTARTING.name(), "worker1", null));
-        tasks.add(new TaskState(4, AbstractStatus.State.DESTROYED.name(), "worker1", null));
-        tasks.add(new TaskState(5, AbstractStatus.State.RUNNING.name(), "worker1", null));
-        tasks.add(new TaskState(6, AbstractStatus.State.RUNNING.name(), "worker1", null));
+        tasks.add(new TaskState(1, AbstractStatus.State.RUNNING.name(), "worker1", null, null));
+        tasks.add(new TaskState(2, AbstractStatus.State.PAUSED.name(), "worker1", null, null));
+        tasks.add(new TaskState(3, AbstractStatus.State.RESTARTING.name(), "worker1", null, null));
+        tasks.add(new TaskState(4, AbstractStatus.State.DESTROYED.name(), "worker1", null, null));
+        tasks.add(new TaskState(5, AbstractStatus.State.RUNNING.name(), "worker1", null, null));
+        tasks.add(new TaskState(6, AbstractStatus.State.RUNNING.name(), "worker1", null, null));
         ConnectorStateInfo connectorStateInfo = new ConnectorStateInfo(CONNECTOR_NAME, state, tasks, ConnectorType.SOURCE);
 
         RestartRequest restartRequest = new RestartRequest(CONNECTOR_NAME, false, true);
@@ -61,13 +59,11 @@ public class RestartPlanTest {
     @Test
     public void testNoRestartsPlan() {
         ConnectorStateInfo.ConnectorState state = new ConnectorStateInfo.ConnectorState(
-                AbstractStatus.State.RUNNING.name(),
-                "foo",
-                null
+                AbstractStatus.State.RUNNING.name(), "foo", null, null
         );
         List<TaskState> tasks = new ArrayList<>();
-        tasks.add(new TaskState(1, AbstractStatus.State.RUNNING.name(), "worker1", null));
-        tasks.add(new TaskState(2, AbstractStatus.State.PAUSED.name(), "worker1", null));
+        tasks.add(new TaskState(1, AbstractStatus.State.RUNNING.name(), "worker1", null, null));
+        tasks.add(new TaskState(2, AbstractStatus.State.PAUSED.name(), "worker1", null, null));
         ConnectorStateInfo connectorStateInfo = new ConnectorStateInfo(CONNECTOR_NAME, state, tasks, ConnectorType.SOURCE);
         RestartRequest restartRequest = new RestartRequest(CONNECTOR_NAME, false, true);
         RestartPlan restartPlan = new RestartPlan(restartRequest, connectorStateInfo);
@@ -81,13 +77,11 @@ public class RestartPlanTest {
     @Test
     public void testRestartsOnlyConnector() {
         ConnectorStateInfo.ConnectorState state = new ConnectorStateInfo.ConnectorState(
-                AbstractStatus.State.RESTARTING.name(),
-                "foo",
-                null
+                AbstractStatus.State.RESTARTING.name(), "foo", null, null
         );
         List<TaskState> tasks = new ArrayList<>();
-        tasks.add(new TaskState(1, AbstractStatus.State.RUNNING.name(), "worker1", null));
-        tasks.add(new TaskState(2, AbstractStatus.State.PAUSED.name(), "worker1", null));
+        tasks.add(new TaskState(1, AbstractStatus.State.RUNNING.name(), "worker1", null, null));
+        tasks.add(new TaskState(2, AbstractStatus.State.PAUSED.name(), "worker1", null, null));
         ConnectorStateInfo connectorStateInfo = new ConnectorStateInfo(CONNECTOR_NAME, state, tasks, ConnectorType.SOURCE);
         RestartRequest restartRequest = new RestartRequest(CONNECTOR_NAME, false, true);
         RestartPlan restartPlan = new RestartPlan(restartRequest, connectorStateInfo);
