@@ -144,46 +144,6 @@ public class ReplaceFieldTest {
         assertEquals(true, updatedValue.getBoolean("bar"));
     }
 
-    @Test
-    public void testIncludeBackwardsCompatibility() {
-        final Map<String, String> props = new HashMap<>();
-        props.put("whitelist", "abc,foo");
-        props.put("renames", "abc:xyz,foo:bar");
-
-        xform.configure(props);
-
-        final SinkRecord record = new SinkRecord("test", 0, null, null, null, null, 0);
-        final SinkRecord transformedRecord = xform.apply(record);
-
-        assertNull(transformedRecord.value());
-        assertNull(transformedRecord.valueSchema());
-    }
-
-    @SuppressWarnings("unchecked")
-    @Test
-    public void testExcludeBackwardsCompatibility() {
-        final Map<String, String> props = new HashMap<>();
-        props.put("blacklist", "dont");
-        props.put("renames", "abc:xyz,foo:bar");
-
-        xform.configure(props);
-
-        final Map<String, Object> value = new HashMap<>();
-        value.put("dont", "whatever");
-        value.put("abc", 42);
-        value.put("foo", true);
-        value.put("etc", "etc");
-
-        final SinkRecord record = new SinkRecord("test", 0, null, null, null, value, 0);
-        final SinkRecord transformedRecord = xform.apply(record);
-
-        final Map<String, Object> updatedValue = (Map<String, Object>) transformedRecord.value();
-        assertEquals(3, updatedValue.size());
-        assertEquals(42, updatedValue.get("xyz"));
-        assertEquals(true, updatedValue.get("bar"));
-        assertEquals("etc", updatedValue.get("etc"));
-    }
-
     @Test
     public void testReplaceFieldVersionRetrievedFromAppInfoParser() {
         assertEquals(AppInfoParser.getVersion(), xform.version());
