@@ -18,29 +18,27 @@
 package kafka.server.builders;
 
 import kafka.log.LogManager;
-import kafka.server.BrokerTopicStats;
-import kafka.server.metadata.ConfigRepository;
 
 import org.apache.kafka.common.utils.Time;
-import org.apache.kafka.server.common.MetadataVersion;
+import org.apache.kafka.metadata.ConfigRepository;
 import org.apache.kafka.server.config.ServerLogConfigs;
 import org.apache.kafka.server.util.Scheduler;
 import org.apache.kafka.storage.internals.log.CleanerConfig;
 import org.apache.kafka.storage.internals.log.LogConfig;
 import org.apache.kafka.storage.internals.log.LogDirFailureChannel;
 import org.apache.kafka.storage.internals.log.ProducerStateManagerConfig;
+import org.apache.kafka.storage.log.metrics.BrokerTopicStats;
 
 import java.io.File;
-import java.util.Collections;
 import java.util.List;
 
-import scala.collection.JavaConverters;
+import scala.jdk.javaapi.CollectionConverters;
 
 
 public class LogManagerBuilder {
     private static final int PRODUCER_ID_EXPIRATION_CHECK_INTERVAL_MS = 600000;
     private List<File> logDirs = null;
-    private List<File> initialOfflineDirs = Collections.emptyList();
+    private List<File> initialOfflineDirs = List.of();
     private ConfigRepository configRepository = null;
     private LogConfig initialDefaultConfig = null;
     private CleanerConfig cleanerConfig = null;
@@ -51,12 +49,10 @@ public class LogManagerBuilder {
     private long retentionCheckMs = 1000L;
     private int maxTransactionTimeoutMs = 15 * 60 * 1000;
     private ProducerStateManagerConfig producerStateManagerConfig = new ProducerStateManagerConfig(60000, false);
-    private MetadataVersion interBrokerProtocolVersion = MetadataVersion.latestProduction();
     private Scheduler scheduler = null;
     private BrokerTopicStats brokerTopicStats = null;
     private LogDirFailureChannel logDirFailureChannel = null;
     private Time time = Time.SYSTEM;
-    private boolean keepPartitionMetadataFile = true;
     private boolean remoteStorageSystemEnable = false;
     private long initialTaskDelayMs = ServerLogConfigs.LOG_INITIAL_TASK_DELAY_MS_DEFAULT;
 
@@ -120,11 +116,6 @@ public class LogManagerBuilder {
         return this;
     }
 
-    public LogManagerBuilder setInterBrokerProtocolVersion(MetadataVersion interBrokerProtocolVersion) {
-        this.interBrokerProtocolVersion = interBrokerProtocolVersion;
-        return this;
-    }
-
     public LogManagerBuilder setScheduler(Scheduler scheduler) {
         this.scheduler = scheduler;
         return this;
@@ -145,11 +136,6 @@ public class LogManagerBuilder {
         return this;
     }
 
-    public LogManagerBuilder setKeepPartitionMetadataFile(boolean keepPartitionMetadataFile) {
-        this.keepPartitionMetadataFile = keepPartitionMetadataFile;
-        return this;
-    }
-
     public LogManagerBuilder setRemoteStorageSystemEnable(boolean remoteStorageSystemEnable) {
         this.remoteStorageSystemEnable = remoteStorageSystemEnable;
         return this;
@@ -168,9 +154,8 @@ public class LogManagerBuilder {
         if (scheduler == null) throw new RuntimeException("you must set scheduler");
         if (brokerTopicStats == null) throw new RuntimeException("you must set brokerTopicStats");
         if (logDirFailureChannel == null) throw new RuntimeException("you must set logDirFailureChannel");
-
-        return new LogManager(JavaConverters.asScalaIteratorConverter(logDirs.iterator()).asScala().toSeq(),
-                              JavaConverters.asScalaIteratorConverter(initialOfflineDirs.iterator()).asScala().toSeq(),
+        return new LogManager(CollectionConverters.asScala(logDirs).toSeq(),
+                              CollectionConverters.asScala(initialOfflineDirs).toSeq(),
                               configRepository,
                               initialDefaultConfig,
                               cleanerConfig,
@@ -182,12 +167,10 @@ public class LogManagerBuilder {
                               maxTransactionTimeoutMs,
                               producerStateManagerConfig,
                               PRODUCER_ID_EXPIRATION_CHECK_INTERVAL_MS,
-                              interBrokerProtocolVersion,
                               scheduler,
                               brokerTopicStats,
                               logDirFailureChannel,
                               time,
-                              keepPartitionMetadataFile,
                               remoteStorageSystemEnable,
                               initialTaskDelayMs);
     }
