@@ -17,9 +17,7 @@
 
 package kafka.server.metadata
 
-import kafka.server.{CachedControllerId, KRaftCachedControllerId, MetadataCache}
 import kafka.utils.Logging
-import org.apache.kafka.admin.BrokerMetadata
 import org.apache.kafka.common._
 import org.apache.kafka.common.config.ConfigResource
 import org.apache.kafka.common.errors.InvalidTopicException
@@ -31,15 +29,15 @@ import org.apache.kafka.common.network.ListenerName
 import org.apache.kafka.common.protocol.Errors
 import org.apache.kafka.common.requests.MetadataResponse
 import org.apache.kafka.image.MetadataImage
-import org.apache.kafka.metadata.{BrokerRegistration, LeaderAndIsr, PartitionRegistration, Replicas}
+import org.apache.kafka.metadata.{BrokerRegistration, LeaderAndIsr, MetadataCache, PartitionRegistration, Replicas}
 import org.apache.kafka.server.common.{FinalizedFeatures, KRaftVersion, MetadataVersion}
 
 import java.util
 import java.util.concurrent.ThreadLocalRandom
-import java.util.function.Supplier
-import java.util.{Collections, Properties}
+import java.util.function.{Predicate, Supplier}
+import java.util.stream.Collectors
+import java.util.Properties
 import scala.collection.mutable.ListBuffer
-import scala.collection.{Map, Seq, Set, mutable}
 import scala.jdk.CollectionConverters._
 import scala.jdk.OptionConverters.RichOptional
 import scala.util.control.Breaks._
@@ -48,7 +46,7 @@ import scala.util.control.Breaks._
 class KRaftMetadataCache(
   val brokerId: Int,
   val kraftVersionSupplier: Supplier[KRaftVersion]
-) extends MetadataCache with Logging with ConfigRepository {
+) extends MetadataCache with Logging {
   this.logIdent = s"[MetadataCache brokerId=$brokerId] "
 
   // This is the cache state. Every MetadataImage instance is immutable, and updates
@@ -150,9 +148,7 @@ class KRaftMetadataCache(
    * @param topicName                   The name of the topic.
    * @param listenerName                The listener name.
    * @param startIndex                  The smallest index of the partitions to be included in the result.
-   * @param upperIndex                  The upper limit of the index of the partitions to be included in the result.
-   *                                    Note that, the upper index can be larger than the largest partition index in
-   *                                    this topic.
+   *                                    
    * @return                            A collection of topic partition metadata and next partition index (-1 means
    *                                    no next partition).
    */
@@ -241,43 +237,29 @@ class KRaftMetadataCache(
   }
 
   // errorUnavailableEndpoints exists to support v0 MetadataResponses
-  override def getTopicMetadata(topics: Set[String],
+  override def getTopicMetadata(topics: util.Set[String],
                                 listenerName: ListenerName,
                                 errorUnavailableEndpoints: Boolean = false,
-                                errorUnavailableListeners: Boolean = false): Seq[MetadataResponseTopic] = {
+                                errorUnavailableListeners: Boolean = false): util.List[MetadataResponseTopic] = {
     val image = _currentImage
-    topics.toSeq.flatMap { topic =>
-      getPartitionMetadata(image, topic, listenerName, errorUnavailableEndpoints, errorUnavailableListeners).map { partitionMetadata =>
-        new MetadataResponseTopic()
-          .setErrorCode(Errors.NONE.code)
-          .setName(topic)
-          .setTopicId(Option(image.topics().getTopic(topic).id()).getOrElse(Uuid.ZERO_UUID))
-          .setIsInternal(Topic.isInternal(topic))
-          .setPartitions(partitionMetadata.toBuffer.asJava)
+    topics.stream().flatMap(topic =>
+      getPartitionMetadata(image, topic, listenerName, errorUnavailableEndpoints, errorUnavailableListeners) match {
+        case Some(partitionMetadata) =>
+          util.stream.Stream.of(new MetadataResponseTopic()
+            .setErrorCode(Errors.NONE.code)
+            .setName(topic)
+            .setTopicId(Option(image.topics().getTopic(topic).id()).getOrElse(Uuid.ZERO_UUID))
+            .setIsInternal(Topic.isInternal(topic))
+            .setPartitions(partitionMetadata.toBuffer.asJava))
+        case None => util.stream.Stream.empty()
       }
-    }
+    ).collect(Collectors.toList())
   }
 
-  /**
-   * Get the topic metadata for the given topics.
-   *
-   * The quota is used to limit the number of partitions to return. The NextTopicPartition field points to the first
-   * partition can't be returned due the limit.
-   * If a topic can't return any partition due to quota limit reached, this topic will not be included in the response.
-   *
-   * Note, the topics should be sorted in alphabetical order. The topics in the DescribeTopicPartitionsResponseData
-   * will also be sorted in alphabetical order.
-   *
-   * @param topics                        The iterator of topics and their corresponding first partition id to fetch.
-   * @param listenerName                  The listener name.
-   * @param firstTopicPartitionStartIndex The start partition index for the first topic
-   * @param maximumNumberOfPartitions     The max number of partitions to return.
-   * @param ignoreTopicsWithExceptions    Whether ignore the topics with exception.
-   */
-  def getTopicMetadataForDescribeTopicResponse(
-    topics: Iterator[String],
+  override def describeTopicResponse(
+    topics: util.Iterator[String],
     listenerName: ListenerName,
-    topicPartitionStartIndex: String => Int,
+    topicPartitionStartIndex: util.function.Function[String, Integer],
     maximumNumberOfPartitions: Int,
     ignoreTopicsWithExceptions: Boolean
   ): DescribeTopicPartitionsResponseData = {
@@ -285,7 +267,7 @@ class KRaftMetadataCache(
     var remaining = maximumNumberOfPartitions
     val result = new DescribeTopicPartitionsResponseData()
     breakable {
-      topics.foreach { topicName =>
+      topics.forEachRemaining { topicName =>
         if (remaining > 0) {
           val (partitionResponse, nextPartition) =
             getPartitionMetadataForDescribeTopicResponse(
@@ -338,93 +320,81 @@ class KRaftMetadataCache(
     result
   }
 
-  override def getAllTopics(): Set[String] = _currentImage.topics().topicsByName().keySet().asScala
+  override def getAllTopics(): util.Set[String] = _currentImage.topics().topicsByName().keySet()
 
-  override def getTopicPartitions(topicName: String): Set[TopicPartition] = {
-    Option(_currentImage.topics().getTopic(topicName)) match {
-      case None => Set.empty
-      case Some(topic) => topic.partitions().keySet().asScala.map(new TopicPartition(topicName, _))
-    }
-  }
+  override def getTopicId(topicName: String): Uuid = util.Optional.ofNullable(_currentImage.topics.topicsByName.get(topicName))
+    .map(_.id)
+    .orElse(Uuid.ZERO_UUID)
 
-  override def getTopicId(topicName: String): Uuid = _currentImage.topics().topicsByName().asScala.get(topicName).map(_.id()).getOrElse(Uuid.ZERO_UUID)
-
-  override def getTopicName(topicId: Uuid): Option[String] = _currentImage.topics().topicsById.asScala.get(topicId).map(_.name())
+  override def getTopicName(topicId: Uuid): util.Optional[String] = util.Optional.ofNullable(_currentImage.topics().topicsById().get(topicId)).map(t => t.name)
 
   override def hasAliveBroker(brokerId: Int): Boolean = {
     Option(_currentImage.cluster.broker(brokerId)).count(!_.fenced()) == 1
   }
 
-  def isBrokerFenced(brokerId: Int): Boolean = {
+  override def isBrokerFenced(brokerId: Int): Boolean = {
     Option(_currentImage.cluster.broker(brokerId)).count(_.fenced) == 1
   }
 
-  def isBrokerShuttingDown(brokerId: Int): Boolean = {
+  override def isBrokerShuttingDown(brokerId: Int): Boolean = {
     Option(_currentImage.cluster.broker(brokerId)).count(_.inControlledShutdown) == 1
   }
 
-  override def getAliveBrokers(): Iterable[BrokerMetadata] = getAliveBrokers(_currentImage)
-
-  private def getAliveBrokers(image: MetadataImage): Iterable[BrokerMetadata] = {
-    image.cluster().brokers().values().asScala.filterNot(_.fenced()).
-      map(b => new BrokerMetadata(b.id, b.rack))
+  override def getAliveBrokerNode(brokerId: Int, listenerName: ListenerName): util.Optional[Node] = {
+    util.Optional.ofNullable(_currentImage.cluster().broker(brokerId))
+      .filter(Predicate.not(_.fenced))
+      .flatMap(broker => broker.node(listenerName.value))
   }
 
-  override def getAliveBrokerNode(brokerId: Int, listenerName: ListenerName): Option[Node] = {
-    Option(_currentImage.cluster().broker(brokerId)).filterNot(_.fenced()).
-      flatMap(_.node(listenerName.value()).toScala)
+  override def getAliveBrokerNodes(listenerName: ListenerName): util.List[Node] = {
+    _currentImage.cluster.brokers.values.stream
+      .filter(Predicate.not(_.fenced))
+      .flatMap(broker => broker.node(listenerName.value).stream)
+      .collect(Collectors.toList())
   }
 
-  override def getAliveBrokerNodes(listenerName: ListenerName): Seq[Node] = {
-    _currentImage.cluster().brokers().values().asScala.filterNot(_.fenced()).
-      flatMap(_.node(listenerName.value()).toScala).toSeq
+  override def getBrokerNodes(listenerName: ListenerName): util.List[Node] = {
+    _currentImage.cluster.brokers.values.stream
+      .flatMap(broker => broker.node(listenerName.value).stream)
+      .collect(Collectors.toList())
   }
 
-  override def getBrokerNodes(listenerName: ListenerName): Seq[Node] = {
-    _currentImage.cluster().brokers().values().asScala.flatMap(_.node(listenerName.value()).asScala).toSeq
-  }
-
-  override def getLeaderAndIsr(topicName: String, partitionId: Int): Option[LeaderAndIsr] = {
-    Option(_currentImage.topics().getTopic(topicName)).
-      flatMap(topic => Option(topic.partitions().get(partitionId))).
-      flatMap(partition => Some(new LeaderAndIsr(partition.leader, partition.leaderEpoch,
+  override def getLeaderAndIsr(topicName: String, partitionId: Int): util.Optional[LeaderAndIsr] = {
+    util.Optional.ofNullable(_currentImage.topics().getTopic(topicName)).
+      flatMap(topic => util.Optional.ofNullable(topic.partitions().get(partitionId))).
+      flatMap(partition => util.Optional.ofNullable(new LeaderAndIsr(partition.leader, partition.leaderEpoch,
         util.Arrays.asList(partition.isr.map(i => i: java.lang.Integer): _*), partition.leaderRecoveryState, partition.partitionEpoch)))
   }
 
-  override def numPartitions(topicName: String): Option[Int] = {
-    Option(_currentImage.topics().getTopic(topicName)).
+  override def numPartitions(topicName: String): util.Optional[Integer] = {
+    util.Optional.ofNullable(_currentImage.topics().getTopic(topicName)).
       map(topic => topic.partitions().size())
   }
 
-  override def topicNamesToIds(): util.Map[String, Uuid] = _currentImage.topics.topicNameToIdView()
-
   override def topicIdsToNames(): util.Map[Uuid, String] = _currentImage.topics.topicIdToNameView()
 
-  override def topicIdInfo(): (util.Map[String, Uuid], util.Map[Uuid, String]) = {
-    val image = _currentImage
-    (image.topics.topicNameToIdView(), image.topics.topicIdToNameView())
-  }
+  override def topicNamesToIds(): util.Map[String, Uuid] = _currentImage.topics().topicNameToIdView()
 
   // if the leader is not known, return None;
   // if the leader is known and corresponding node is available, return Some(node)
   // if the leader is known but corresponding node with the listener name is not available, return Some(NO_NODE)
-  override def getPartitionLeaderEndpoint(topicName: String, partitionId: Int, listenerName: ListenerName): Option[Node] = {
+  override def getPartitionLeaderEndpoint(topicName: String, partitionId: Int, listenerName: ListenerName): util.Optional[Node] = {
     val image = _currentImage
     Option(image.topics().getTopic(topicName)) match {
-      case None => None
+      case None => util.Optional.empty()
       case Some(topic) => Option(topic.partitions().get(partitionId)) match {
-        case None => None
+        case None => util.Optional.empty()
         case Some(partition) => Option(image.cluster().broker(partition.leader)) match {
-          case None => Some(Node.noNode)
-          case Some(broker) => Some(broker.node(listenerName.value()).orElse(Node.noNode()))
+          case None => util.Optional.of(Node.noNode)
+          case Some(broker) => util.Optional.of(broker.node(listenerName.value()).orElse(Node.noNode()))
         }
       }
     }
   }
 
-  override def getPartitionReplicaEndpoints(tp: TopicPartition, listenerName: ListenerName): Map[Int, Node] = {
+  override def getPartitionReplicaEndpoints(tp: TopicPartition, listenerName: ListenerName): util.Map[Integer, Node] = {
     val image = _currentImage
-    val result = new mutable.HashMap[Int, Node]()
+    val result = new util.HashMap[Integer, Node]()
     Option(image.topics().getTopic(tp.topic())).foreach { topic =>
       Option(topic.partitions().get(tp.partition())).foreach { partition =>
         partition.replicas.foreach { replicaId =>
@@ -441,74 +411,25 @@ class KRaftMetadataCache(
     result
   }
 
-  /**
-   * Choose a random broker node to report as the controller. We do this because we want
-   * the client to send requests destined for the controller to a random broker.
-   * Clients do not have direct access to the controller in the KRaft world, as explained
-   * in KIP-590.
-   */
-  override def getControllerId: Option[CachedControllerId] =
-    getRandomAliveBroker(_currentImage).map(KRaftCachedControllerId)
-
-  override def getRandomAliveBrokerId: Option[Int] = {
+  override def getRandomAliveBrokerId: util.Optional[Integer] = {
     getRandomAliveBroker(_currentImage)
   }
 
-  private def getRandomAliveBroker(image: MetadataImage): Option[Int] = {
-    val aliveBrokers = getAliveBrokers(image).toList
+  private def getRandomAliveBroker(image: MetadataImage): util.Optional[Integer] = {
+    val aliveBrokers = image.cluster().brokers().values().stream()
+      .filter(Predicate.not(_.fenced))
+      .map(_.id()).toList
     if (aliveBrokers.isEmpty) {
-      None
+      util.Optional.empty()
     } else {
-      Some(aliveBrokers(ThreadLocalRandom.current().nextInt(aliveBrokers.size)).id)
+      util.Optional.of(aliveBrokers.get(ThreadLocalRandom.current().nextInt(aliveBrokers.size)))
     }
   }
 
-  def getAliveBrokerEpoch(brokerId: Int): Option[Long] = {
-    Option(_currentImage.cluster().broker(brokerId)).filterNot(_.fenced()).
-      map(brokerRegistration => brokerRegistration.epoch())
-  }
-
-  override def getClusterMetadata(clusterId: String, listenerName: ListenerName): Cluster = {
-    val image = _currentImage
-    val nodes = new util.HashMap[Integer, Node]
-    image.cluster().brokers().values().forEach { broker =>
-      if (!broker.fenced()) {
-        broker.node(listenerName.value()).toScala.foreach { node =>
-          nodes.put(broker.id(), node)
-        }
-      }
-    }
-
-    def node(id: Int): Node = {
-      Option(nodes.get(id)).getOrElse(Node.noNode())
-    }
-
-    val partitionInfos = new util.ArrayList[PartitionInfo]
-    val internalTopics = new util.HashSet[String]
-
-    image.topics().topicsByName().values().forEach { topic =>
-      topic.partitions().forEach { (key, value) =>
-        val partitionId = key
-        val partition = value
-        partitionInfos.add(new PartitionInfo(topic.name(),
-          partitionId,
-          node(partition.leader),
-          partition.replicas.map(replica => node(replica)),
-          partition.isr.map(replica => node(replica)),
-          getOfflineReplicas(image, partition, listenerName).asScala.
-            map(replica => node(replica)).toArray))
-        if (Topic.isInternal(topic.name())) {
-          internalTopics.add(topic.name())
-        }
-      }
-    }
-    val controllerNode = node(getRandomAliveBroker(image).getOrElse(-1))
-    // Note: the constructor of Cluster does not allow us to reference unregistered nodes.
-    // So, for example, if partition foo-0 has replicas [1, 2] but broker 2 is not
-    // registered, we pass its replicas as [1, -1]. This doesn't make a lot of sense, but
-    // we are duplicating the behavior of ZkMetadataCache, for now.
-    new Cluster(clusterId, nodes.values(),
-      partitionInfos, Collections.emptySet(), internalTopics, controllerNode)
+  override def getAliveBrokerEpoch(brokerId: Int): util.Optional[java.lang.Long] = {
+    util.Optional.ofNullable(_currentImage.cluster().broker(brokerId))
+      .filter(Predicate.not(_.fenced))
+      .map(brokerRegistration => brokerRegistration.epoch())
   }
 
   override def contains(topicName: String): Boolean =
@@ -532,11 +453,11 @@ class KRaftMetadataCache(
   override def config(configResource: ConfigResource): Properties =
     _currentImage.configs().configProperties(configResource)
 
-  def describeClientQuotas(request: DescribeClientQuotasRequestData): DescribeClientQuotasResponseData = {
+  override def describeClientQuotas(request: DescribeClientQuotasRequestData): DescribeClientQuotasResponseData = {
     _currentImage.clientQuotas().describe(request)
   }
 
-  def describeScramCredentials(request: DescribeUserScramCredentialsRequestData): DescribeUserScramCredentialsResponseData = {
+  override def describeScramCredentials(request: DescribeUserScramCredentialsRequestData): DescribeUserScramCredentialsResponseData = {
     _currentImage.scram().describe(request)
   }
 
@@ -552,8 +473,7 @@ class KRaftMetadataCache(
     new FinalizedFeatures(
       image.features().metadataVersionOrThrow(),
       finalizedFeatures,
-      image.highestOffsetAndEpoch().offset,
-      true)
+      image.highestOffsetAndEpoch().offset)
   }
 }
 
