@@ -31,7 +31,6 @@ import java.io.File;
 import java.io.FileWriter;
 import java.io.IOException;
 import java.util.ArrayList;
-import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
@@ -246,7 +245,7 @@ public class JaasTestUtils {
                         KAFKA_SCRAM_PASSWORD_2,
                         KAFKA_OAUTH_BEARER_USER_2,
                         SERVICE_NAME)
-                ).map(Collections::singletonList).orElse(Collections.emptyList()));
+                ).map(List::of).orElse(List.of()));
     }
 
     private static void writeToFile(File file, List<JaasSection> jaasSections) throws IOException {
@@ -256,23 +255,17 @@ public class JaasTestUtils {
     }
 
     public static boolean usesSslTransportLayer(SecurityProtocol securityProtocol) {
-        switch (securityProtocol) {
-            case SSL:
-            case SASL_SSL:
-                return true;
-            default:
-                return false;
-        }
+        return switch (securityProtocol) {
+            case SSL, SASL_SSL -> true;
+            default -> false;
+        };
     }
 
     public static boolean usesSaslAuthentication(SecurityProtocol securityProtocol) {
-        switch (securityProtocol) {
-            case SASL_PLAINTEXT:
-            case SASL_SSL:
-                return true;
-            default:
-                return false;
-        }
+        return switch (securityProtocol) {
+            case SASL_PLAINTEXT, SASL_SSL -> true;
+            default -> false;
+        };
     }
 
     public static Properties sslConfigs(ConnectionMode mode,
