@@ -16,13 +16,12 @@
  */
 package kafka.server.logger;
 
-import kafka.utils.Log4jController;
-
 import org.apache.kafka.clients.admin.AlterConfigOp;
 import org.apache.kafka.clients.admin.AlterConfigOp.OpType;
 import org.apache.kafka.common.errors.InvalidConfigurationException;
 import org.apache.kafka.common.errors.InvalidRequestException;
 import org.apache.kafka.common.message.IncrementalAlterConfigsRequestData.AlterableConfig;
+import org.apache.kafka.server.logger.LoggingController;
 
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.Test;
@@ -31,7 +30,7 @@ import org.junit.jupiter.params.provider.ValueSource;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import java.util.Arrays;
+import java.util.List;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
 
@@ -42,7 +41,7 @@ public class RuntimeLoggerManagerTest {
 
     @Test
     public void testValidateSetLogLevelConfig() {
-        MANAGER.validateLogLevelConfigs(Arrays.asList(new AlterableConfig().
+        MANAGER.validateLogLevelConfigs(List.of(new AlterableConfig().
             setName(LOG.getName()).
             setConfigOperation(OpType.SET.id()).
             setValue("TRACE")));
@@ -50,7 +49,7 @@ public class RuntimeLoggerManagerTest {
 
     @Test
     public void testValidateDeleteLogLevelConfig() {
-        MANAGER.validateLogLevelConfigs(Arrays.asList(new AlterableConfig().
+        MANAGER.validateLogLevelConfigs(List.of(new AlterableConfig().
             setName(LOG.getName()).
             setConfigOperation(OpType.DELETE.id()).
             setValue("")));
@@ -62,7 +61,7 @@ public class RuntimeLoggerManagerTest {
         OpType opType = AlterConfigOp.OpType.forId(id);
         assertEquals(opType + " operation is not allowed for the BROKER_LOGGER resource",
             Assertions.assertThrows(InvalidRequestException.class,
-                () -> MANAGER.validateLogLevelConfigs(Arrays.asList(new AlterableConfig().
+                () -> MANAGER.validateLogLevelConfigs(List.of(new AlterableConfig().
                     setName(LOG.getName()).
                     setConfigOperation(id).
                     setValue("TRACE")))).getMessage());
@@ -73,7 +72,7 @@ public class RuntimeLoggerManagerTest {
         assertEquals("Cannot set the log level of " + LOG.getName() + " to BOGUS as it is not " +
             "a supported log level. Valid log levels are DEBUG, ERROR, FATAL, INFO, TRACE, WARN",
             Assertions.assertThrows(InvalidConfigurationException.class,
-                () -> MANAGER.validateLogLevelConfigs(Arrays.asList(new AlterableConfig().
+                () -> MANAGER.validateLogLevelConfigs(List.of(new AlterableConfig().
                     setName(LOG.getName()).
                     setConfigOperation(OpType.SET.id()).
                     setValue("BOGUS")))).getMessage());
@@ -81,19 +80,19 @@ public class RuntimeLoggerManagerTest {
 
     @Test
     public void testValidateSetRootLogLevelConfig() {
-        MANAGER.validateLogLevelConfigs(Arrays.asList(new AlterableConfig().
-                setName(Log4jController.ROOT_LOGGER()).
+        MANAGER.validateLogLevelConfigs(List.of(new AlterableConfig().
+                setName(LoggingController.ROOT_LOGGER).
                 setConfigOperation(OpType.SET.id()).
                 setValue("TRACE")));
     }
 
     @Test
     public void testValidateRemoveRootLogLevelConfigNotAllowed() {
-        assertEquals("Removing the log level of the " + Log4jController.ROOT_LOGGER() +
+        assertEquals("Removing the log level of the " + LoggingController.ROOT_LOGGER +
             " logger is not allowed",
             Assertions.assertThrows(InvalidRequestException.class,
-                () -> MANAGER.validateLogLevelConfigs(Arrays.asList(new AlterableConfig().
-                    setName(Log4jController.ROOT_LOGGER()).
+                () -> MANAGER.validateLogLevelConfigs(List.of(new AlterableConfig().
+                    setName(LoggingController.ROOT_LOGGER).
                     setConfigOperation(OpType.DELETE.id()).
                     setValue("")))).getMessage());
     }
