@@ -15,7 +15,7 @@ package kafka.api
 
 import java.{time, util}
 import java.util.concurrent._
-import java.util.{Collections, Properties}
+import java.util.Properties
 import kafka.server.KafkaConfig
 import kafka.utils.{Logging, TestInfoUtils, TestUtils}
 import org.apache.kafka.clients.consumer._
@@ -98,9 +98,9 @@ class ConsumerBounceTest extends AbstractConsumerTest with Logging {
     }
   }
 
-  @ParameterizedTest(name = TestInfoUtils.TestWithParameterizedQuorumAndGroupProtocolNames)
-  @MethodSource(Array("getTestQuorumAndGroupProtocolParametersAll"))
-  def testConsumptionWithBrokerFailures(quorum: String, groupProtocol: String): Unit = consumeWithBrokerFailures(10)
+  @ParameterizedTest(name = TestInfoUtils.TestWithParameterizedGroupProtocolNames)
+  @MethodSource(Array("getTestGroupProtocolParametersAll"))
+  def testConsumptionWithBrokerFailures(groupProtocol: String): Unit = consumeWithBrokerFailures(10)
 
   /*
    * 1. Produce a bunch of messages
@@ -114,7 +114,7 @@ class ConsumerBounceTest extends AbstractConsumerTest with Logging {
     var consumed = 0L
     val consumer = createConsumer()
 
-    consumer.subscribe(Collections.singletonList(topic))
+    consumer.subscribe(util.List.of(topic))
 
     val scheduler = new BounceBrokerScheduler(numIters)
     try {
@@ -130,10 +130,10 @@ class ConsumerBounceTest extends AbstractConsumerTest with Logging {
 
         if (records.nonEmpty) {
           consumer.commitSync()
-          assertEquals(consumer.position(tp), consumer.committed(Set(tp).asJava).get(tp).offset)
+          assertEquals(consumer.position(tp), consumer.committed(util.Set.of(tp)).get(tp).offset)
 
           if (consumer.position(tp) == numRecords) {
-            consumer.seekToBeginning(Collections.emptyList())
+            consumer.seekToBeginning(util.List.of())
             consumed = 0
           }
         }
@@ -143,9 +143,9 @@ class ConsumerBounceTest extends AbstractConsumerTest with Logging {
     }
   }
 
-  @ParameterizedTest(name = TestInfoUtils.TestWithParameterizedQuorumAndGroupProtocolNames)
-  @MethodSource(Array("getTestQuorumAndGroupProtocolParametersAll"))
-  def testSeekAndCommitWithBrokerFailures(quorum: String, groupProtocol: String): Unit = seekAndCommitWithBrokerFailures(5)
+  @ParameterizedTest(name = TestInfoUtils.TestWithParameterizedGroupProtocolNames)
+  @MethodSource(Array("getTestGroupProtocolParametersAll"))
+  def testSeekAndCommitWithBrokerFailures(groupProtocol: String): Unit = seekAndCommitWithBrokerFailures(5)
 
   def seekAndCommitWithBrokerFailures(numIters: Int): Unit = {
     val numRecords = 1000
@@ -153,7 +153,7 @@ class ConsumerBounceTest extends AbstractConsumerTest with Logging {
     producerSend(producer, numRecords)
 
     val consumer = createConsumer()
-    consumer.assign(Collections.singletonList(tp))
+    consumer.assign(util.List.of(tp))
     consumer.seek(tp, 0)
 
     // wait until all the followers have synced the last HW with leader
@@ -169,7 +169,7 @@ class ConsumerBounceTest extends AbstractConsumerTest with Logging {
         val coin = TestUtils.random.nextInt(3)
         if (coin == 0) {
           info("Seeking to end of log")
-          consumer.seekToEnd(Collections.emptyList())
+          consumer.seekToEnd(util.List.of())
           assertEquals(numRecords.toLong, consumer.position(tp))
         } else if (coin == 1) {
           val pos = TestUtils.random.nextInt(numRecords).toLong
@@ -179,7 +179,7 @@ class ConsumerBounceTest extends AbstractConsumerTest with Logging {
         } else if (coin == 2) {
           info("Committing offset.")
           consumer.commitSync()
-          assertEquals(consumer.position(tp), consumer.committed(Set(tp).asJava).get(tp).offset)
+          assertEquals(consumer.position(tp), consumer.committed(java.util.Set.of(tp)).get(tp).offset)
         }
       }
     } finally {
@@ -187,14 +187,14 @@ class ConsumerBounceTest extends AbstractConsumerTest with Logging {
     }
   }
 
-  @ParameterizedTest(name = TestInfoUtils.TestWithParameterizedQuorumAndGroupProtocolNames)
-  @MethodSource(Array("getTestQuorumAndGroupProtocolParametersAll"))
-  def testSubscribeWhenTopicUnavailable(quorum: String, groupProtocol: String): Unit = {
+  @ParameterizedTest(name = TestInfoUtils.TestWithParameterizedGroupProtocolNames)
+  @MethodSource(Array("getTestGroupProtocolParametersAll"))
+  def testSubscribeWhenTopicUnavailable(groupProtocol: String): Unit = {
     val numRecords = 1000
     val newtopic = "newtopic"
 
     val consumer = createConsumer()
-    consumer.subscribe(Collections.singleton(newtopic))
+    consumer.subscribe(util.Set.of(newtopic))
     executor.schedule(new Runnable {
         def run(): Unit = createTopic(newtopic, numPartitions = brokerCount, replicationFactor = brokerCount)
       }, 2, TimeUnit.SECONDS)
@@ -239,9 +239,9 @@ class ConsumerBounceTest extends AbstractConsumerTest with Logging {
     receiveExactRecords(poller, numRecords, 10000L)
   }
 
-  @ParameterizedTest(name = TestInfoUtils.TestWithParameterizedQuorumAndGroupProtocolNames)
-  @MethodSource(Array("getTestQuorumAndGroupProtocolParametersAll"))
-  def testClose(quorum: String, groupProtocol: String): Unit = {
+  @ParameterizedTest(name = TestInfoUtils.TestWithParameterizedGroupProtocolNames)
+  @MethodSource(Array("getTestGroupProtocolParametersAll"))
+  def testClose(groupProtocol: String): Unit = {
     val numRecords = 10
     val producer = createProducer()
     producerSend(producer, numRecords)
@@ -287,7 +287,7 @@ class ConsumerBounceTest extends AbstractConsumerTest with Logging {
   private def findCoordinator(group: String): Int = {
     val request = new FindCoordinatorRequest.Builder(new FindCoordinatorRequestData()
       .setKeyType(FindCoordinatorRequest.CoordinatorType.GROUP.id)
-      .setCoordinatorKeys(Collections.singletonList(group))).build()
+      .setCoordinatorKeys(util.List.of(group))).build()
     var nodeId = -1
     TestUtils.waitUntilTrue(() => {
       val response = connectAndReceive[FindCoordinatorResponse](request)
@@ -307,7 +307,7 @@ class ConsumerBounceTest extends AbstractConsumerTest with Logging {
     val consumer1 = createConsumerAndReceive(group1, manualAssign = false, numRecords)
 
     val requestTimeout = 6000
-    if (groupProtocol.equals(GroupProtocol.CLASSIC.name)) {
+    if (groupProtocol.equalsIgnoreCase(GroupProtocol.CLASSIC.name)) {
       this.consumerConfig.setProperty(ConsumerConfig.SESSION_TIMEOUT_MS_CONFIG, "5000")
       this.consumerConfig.setProperty(ConsumerConfig.HEARTBEAT_INTERVAL_MS_CONFIG, "1000")
     }
@@ -327,10 +327,10 @@ class ConsumerBounceTest extends AbstractConsumerTest with Logging {
     * the group should be forced to rebalance when it becomes hosted on a Coordinator with the new config.
     * Then, 1 consumer should be left out of the group.
     */
-  @ParameterizedTest(name = TestInfoUtils.TestWithParameterizedQuorumAndGroupProtocolNames)
-  @MethodSource(Array("getTestQuorumAndGroupProtocolParametersAll"))
+  @ParameterizedTest(name = TestInfoUtils.TestWithParameterizedGroupProtocolNames)
+  @MethodSource(Array("getTestGroupProtocolParametersAll"))
   @Disabled // TODO: To be re-enabled once we can make it less flaky (KAFKA-13421)
-  def testRollingBrokerRestartsWithSmallerMaxGroupSizeConfigDisruptsBigGroup(quorum: String, groupProtocol: String): Unit = {
+  def testRollingBrokerRestartsWithSmallerMaxGroupSizeConfigDisruptsBigGroup(groupProtocol: String): Unit = {
     val group = "group-max-size-test"
     val topic = "group-max-size-test"
     val maxGroupSize = 2
@@ -338,7 +338,7 @@ class ConsumerBounceTest extends AbstractConsumerTest with Logging {
     val partitionCount = consumerCount * 2
 
     this.consumerConfig.setProperty(ConsumerConfig.MAX_POLL_INTERVAL_MS_CONFIG, "60000")
-    if (groupProtocol.equals(GroupProtocol.CLASSIC.name)) {
+    if (groupProtocol.equalsIgnoreCase(GroupProtocol.CLASSIC.name)) {
       this.consumerConfig.setProperty(ConsumerConfig.HEARTBEAT_INTERVAL_MS_CONFIG, "1000")
     }
     this.consumerConfig.setProperty(ConsumerConfig.ENABLE_AUTO_COMMIT_CONFIG, "false")
@@ -371,13 +371,13 @@ class ConsumerBounceTest extends AbstractConsumerTest with Logging {
   /**
     * When we have the consumer group max size configured to X, the X+1th consumer trying to join should receive a fatal exception
     */
-  @ParameterizedTest(name = TestInfoUtils.TestWithParameterizedQuorumAndGroupProtocolNames)
-  @MethodSource(Array("getTestQuorumAndGroupProtocolParametersAll"))
-  def testConsumerReceivesFatalExceptionWhenGroupPassesMaxSize(quorum: String, groupProtocol: String): Unit = {
+  @ParameterizedTest(name = TestInfoUtils.TestWithParameterizedGroupProtocolNames)
+  @MethodSource(Array("getTestGroupProtocolParametersAll"))
+  def testConsumerReceivesFatalExceptionWhenGroupPassesMaxSize(groupProtocol: String): Unit = {
     val group = "fatal-exception-test"
     val topic = "fatal-exception-test"
     this.consumerConfig.setProperty(ConsumerConfig.MAX_POLL_INTERVAL_MS_CONFIG, "60000")
-    if (groupProtocol.equals(GroupProtocol.CLASSIC.name)) {
+    if (groupProtocol.equalsIgnoreCase(GroupProtocol.CLASSIC.name)) {
       this.consumerConfig.setProperty(ConsumerConfig.HEARTBEAT_INTERVAL_MS_CONFIG, "1000")
     }
     this.consumerConfig.setProperty(ConsumerConfig.ENABLE_AUTO_COMMIT_CONFIG, "false")
@@ -412,13 +412,13 @@ class ConsumerBounceTest extends AbstractConsumerTest with Logging {
    * immediately if rebalance is in progress. If brokers are not available,
    * close should terminate immediately without sending leave group.
    */
-  @ParameterizedTest(name = TestInfoUtils.TestWithParameterizedQuorumAndGroupProtocolNames)
-  @MethodSource(Array("getTestQuorumAndGroupProtocolParametersAll"))
-  def testCloseDuringRebalance(quorum: String, groupProtocol: String): Unit = {
+  @ParameterizedTest(name = TestInfoUtils.TestWithParameterizedGroupProtocolNames)
+  @MethodSource(Array("getTestGroupProtocolParametersAll"))
+  def testCloseDuringRebalance(groupProtocol: String): Unit = {
     val topic = "closetest"
     createTopic(topic, 10, brokerCount)
     this.consumerConfig.setProperty(ConsumerConfig.MAX_POLL_INTERVAL_MS_CONFIG, "60000")
-    if (groupProtocol.equals(GroupProtocol.CLASSIC.name)) {
+    if (groupProtocol.equalsIgnoreCase(GroupProtocol.CLASSIC.name)) {
       this.consumerConfig.setProperty(ConsumerConfig.HEARTBEAT_INTERVAL_MS_CONFIG, "1000")
     }
     this.consumerConfig.setProperty(ConsumerConfig.ENABLE_AUTO_COMMIT_CONFIG, "false")
@@ -429,7 +429,7 @@ class ConsumerBounceTest extends AbstractConsumerTest with Logging {
 
     def subscribeAndPoll(consumer: Consumer[Array[Byte], Array[Byte]], revokeSemaphore: Option[Semaphore] = None): Future[Any] = {
       executor.submit(() => {
-        consumer.subscribe(Collections.singletonList(topic))
+        consumer.subscribe(util.List.of(topic))
         revokeSemaphore.foreach(s => s.release())
           consumer.poll(Duration.ofMillis(500))
         }, 0)
@@ -519,7 +519,7 @@ class ConsumerBounceTest extends AbstractConsumerTest with Logging {
     // New instance of consumer should be assigned partitions immediately and should see committed offsets.
     val assignSemaphore = new Semaphore(0)
     val consumer = createConsumerWithGroupId(groupId)
-    consumer.subscribe(Collections.singletonList(topic), new ConsumerRebalanceListener {
+    consumer.subscribe(util.List.of(topic), new ConsumerRebalanceListener {
       def onPartitionsAssigned(partitions: util.Collection[TopicPartition]): Unit = {
         assignSemaphore.release()
       }
@@ -532,7 +532,7 @@ class ConsumerBounceTest extends AbstractConsumerTest with Logging {
     }, "Assignment did not complete on time")
 
     if (committedRecords > 0)
-      assertEquals(committedRecords, consumer.committed(Set(tp).asJava).get(tp).offset)
+      assertEquals(committedRecords, consumer.committed(java.util.Set.of(tp)).get(tp).offset)
     consumer.close()
   }
 
