@@ -18,7 +18,7 @@
 
 package kafka.server
 
-import java.util.{Collections, Objects, Optional, Properties}
+import java.util.{Objects, Optional, Properties}
 import java.util.concurrent.TimeUnit
 import kafka.api.SaslSetup
 import kafka.security.JaasTestUtils
@@ -126,13 +126,13 @@ abstract class MultipleListenersWithSameSecurityProtocolBaseTest extends QuorumT
     servers.head.groupCoordinator.groupMetadataTopicConfigs.entrySet().
       forEach(e => newTopicConfigs.put(e.getKey.toString, e.getValue.toString))
     newTopic.configs(newTopicConfigs)
-    admin.createTopics(java.util.Arrays.asList(newTopic)).all().get(5, TimeUnit.MINUTES)
+    admin.createTopics(java.util.List.of(newTopic)).all().get(5, TimeUnit.MINUTES)
 
     createScramCredentials(admin, JaasTestUtils.KAFKA_SCRAM_USER, JaasTestUtils.KAFKA_SCRAM_PASSWORD)
     TestUtils.ensureConsistentKRaftMetadata(servers, controllerServer)
 
     servers.head.config.listeners.foreach { endPoint =>
-      val listenerName = endPoint.listenerName
+      val listenerName = ListenerName.normalised(endPoint.listener)
 
       val trustStoreFile =
         if (JaasTestUtils.usesSslTransportLayer(endPoint.securityProtocol)) Some(this.trustStoreFile)
@@ -143,7 +143,7 @@ abstract class MultipleListenersWithSameSecurityProtocolBaseTest extends QuorumT
       def addProducerConsumer(listenerName: ListenerName, mechanism: String, saslProps: Option[Properties]): Unit = {
 
         val topic = s"${listenerName.value}${producers.size}"
-        admin.createTopics(java.util.Arrays.asList(new NewTopic(topic, 2, 2.toShort))).all().get(5, TimeUnit.MINUTES)
+        admin.createTopics(java.util.List.of(new NewTopic(topic, 2, 2.toShort))).all().get(5, TimeUnit.MINUTES)
         val clientMetadata = ClientMetadata(listenerName, mechanism, topic)
 
         producers(clientMetadata) = TestUtils.createProducer(bootstrapServers, acks = -1,
@@ -155,7 +155,7 @@ abstract class MultipleListenersWithSameSecurityProtocolBaseTest extends QuorumT
       }
 
       if (JaasTestUtils.usesSaslAuthentication(endPoint.securityProtocol)) {
-        kafkaServerSaslMechanisms(endPoint.listenerName.value).foreach { mechanism =>
+        kafkaServerSaslMechanisms(endPoint.listener).foreach { mechanism =>
           addProducerConsumer(listenerName, mechanism, Some(kafkaClientSaslProperties(mechanism, dynamicJaasConfig = true)))
         }
       } else {
@@ -179,16 +179,16 @@ abstract class MultipleListenersWithSameSecurityProtocolBaseTest extends QuorumT
     * Tests that we can produce and consume to/from all broker-defined listeners and security protocols. We produce
     * with acks=-1 to ensure that replication is also working.
     */
-  @ParameterizedTest(name = TestInfoUtils.TestWithParameterizedQuorumAndGroupProtocolNames)
-  @MethodSource(Array("getTestQuorumAndGroupProtocolParametersAll"))
-  def testProduceConsume(quorum: String, groupProtocol: String): Unit = {
+  @ParameterizedTest(name = TestInfoUtils.TestWithParameterizedGroupProtocolNames)
+  @MethodSource(Array("getTestGroupProtocolParametersAll"))
+  def testProduceConsume(groupProtocol: String): Unit = {
     producers.foreach { case (clientMetadata, producer) =>
       val producerRecords = (1 to 10).map(i => new ProducerRecord(clientMetadata.topic, s"key$i".getBytes,
         s"value$i".getBytes))
       producerRecords.map(producer.send).map(_.get(10, TimeUnit.SECONDS))
 
       val consumer = consumers(clientMetadata)
-      consumer.subscribe(Collections.singleton(clientMetadata.topic))
+      consumer.subscribe(java.util.Set.of(clientMetadata.topic))
       TestUtils.consumeRecords(consumer, producerRecords.size)
     }
   }
