@@ -19,8 +19,9 @@ package kafka.coordinator.transaction
 import java.util
 import java.util.Arrays.asList
 import java.util.Collections
+import java.util.Optional
 import java.util.concurrent.{Callable, Executors, Future}
-import kafka.server.{KafkaConfig, MetadataCache}
+import kafka.server.KafkaConfig
 import kafka.utils.TestUtils
 import org.apache.kafka.clients.{ClientResponse, NetworkClient}
 import org.apache.kafka.common.protocol.{ApiKeys, Errors}
@@ -28,6 +29,8 @@ import org.apache.kafka.common.record.RecordBatch
 import org.apache.kafka.common.requests.{RequestHeader, TransactionResult, WriteTxnMarkersRequest, WriteTxnMarkersResponse}
 import org.apache.kafka.common.utils.MockTime
 import org.apache.kafka.common.{Node, TopicPartition}
+import org.apache.kafka.coordinator.transaction.TransactionState
+import org.apache.kafka.metadata.MetadataCache
 import org.apache.kafka.server.common.{MetadataVersion, TransactionVersion}
 import org.apache.kafka.server.metrics.{KafkaMetricsGroup, KafkaYammerMetrics}
 import org.apache.kafka.server.util.RequestAndCompletionHandler
@@ -66,9 +69,9 @@ class TransactionMarkerChannelManagerTest {
   private val txnTimeoutMs = 0
   private val txnResult = TransactionResult.COMMIT
   private val txnMetadata1 = new TransactionMetadata(transactionalId1, producerId1, producerId1, RecordBatch.NO_PRODUCER_ID,
-    producerEpoch, lastProducerEpoch, txnTimeoutMs, PrepareCommit, mutable.Set[TopicPartition](partition1, partition2), 0L, 0L, TransactionVersion.TV_2)
+    producerEpoch, lastProducerEpoch, txnTimeoutMs, TransactionState.PREPARE_COMMIT, mutable.Set[TopicPartition](partition1, partition2), 0L, 0L, TransactionVersion.TV_2)
   private val txnMetadata2 = new TransactionMetadata(transactionalId2, producerId2, producerId2, RecordBatch.NO_PRODUCER_ID,
-    producerEpoch, lastProducerEpoch, txnTimeoutMs, PrepareCommit, mutable.Set[TopicPartition](partition1), 0L, 0L, TransactionVersion.TV_2)
+    producerEpoch, lastProducerEpoch, txnTimeoutMs, TransactionState.PREPARE_COMMIT, mutable.Set[TopicPartition](partition1), 0L, 0L, TransactionVersion.TV_2)
 
   private val capturedErrorsCallback: ArgumentCaptor[Errors => Unit] = ArgumentCaptor.forClass(classOf[Errors => Unit])
   private val time = new MockTime
@@ -128,7 +131,7 @@ class TransactionMarkerChannelManagerTest {
       ArgumentMatchers.eq(partition1.topic),
       ArgumentMatchers.eq(partition1.partition),
       any())
-    ).thenReturn(Some(broker1))
+    ).thenReturn(Optional.of(broker1))
 
     when(txnStateManager.appendTransactionToLog(
       ArgumentMatchers.eq(transactionalId2),
@@ -197,7 +200,7 @@ class TransactionMarkerChannelManagerTest {
       ArgumentMatchers.eq(partition1.topic),
       ArgumentMatchers.eq(partition1.partition),
       any())
-    ).thenReturn(Some(broker1))
+    ).thenReturn(Optional.of(broker1))
 
     // Build a successful client response.
     val header = new RequestHeader(ApiKeys.WRITE_TXN_MARKERS, 0, "client", 1)
@@ -280,12 +283,12 @@ class TransactionMarkerChannelManagerTest {
       ArgumentMatchers.eq(partition1.topic),
       ArgumentMatchers.eq(partition1.partition),
       any())
-    ).thenReturn(Some(broker1))
+    ).thenReturn(Optional.of(broker1))
     when(metadataCache.getPartitionLeaderEndpoint(
       ArgumentMatchers.eq(partition2.topic),
       ArgumentMatchers.eq(partition2.partition),
       any())
-    ).thenReturn(Some(broker2))
+    ).thenReturn(Optional.of(broker2))
 
     channelManager.addTxnMarkersToSend(coordinatorEpoch, txnResult, txnMetadata1, txnMetadata1.prepareComplete(time.milliseconds()))
     channelManager.addTxnMarkersToSend(coordinatorEpoch, txnResult, txnMetadata2, txnMetadata2.prepareComplete(time.milliseconds()))
@@ -320,12 +323,12 @@ class TransactionMarkerChannelManagerTest {
       ArgumentMatchers.eq(partition1.topic),
       ArgumentMatchers.eq(partition1.partition),
       any())
-    ).thenReturn(None)
+    ).thenReturn(Optional.empty())
     when(metadataCache.getPartitionLeaderEndpoint(
       ArgumentMatchers.eq(partition2.topic),
       ArgumentMatchers.eq(partition2.partition),
       any())
-    ).thenReturn(Some(broker2))
+    ).thenReturn(Optional.of(broker2))
 
     channelManager.addTxnMarkersToSend(coordinatorEpoch, txnResult, txnMetadata1, txnMetadata1.prepareComplete(time.milliseconds()))
 
@@ -344,17 +347,17 @@ class TransactionMarkerChannelManagerTest {
       ArgumentMatchers.eq(partition1.topic),
       ArgumentMatchers.eq(partition1.partition),
       any())
-    ).thenReturn(Some(Node.noNode))
-      .thenReturn(Some(Node.noNode))
-      .thenReturn(Some(Node.noNode))
-      .thenReturn(Some(Node.noNode))
-      .thenReturn(Some(broker1))
-      .thenReturn(Some(broker1))
+    ).thenReturn(Optional.of(Node.noNode))
+      .thenReturn(Optional.of(Node.noNode))
+      .thenReturn(Optional.of(Node.noNode))
+      .thenReturn(Optional.of(Node.noNode))
+      .thenReturn(Optional.of(broker1))
+      .thenReturn(Optional.of(broker1))
     when(metadataCache.getPartitionLeaderEndpoint(
       ArgumentMatchers.eq(partition2.topic),
       ArgumentMatchers.eq(partition2.partition),
       any())
-    ).thenReturn(Some(broker2))
+    ).thenReturn(Optional.of(broker2))
 
     channelManager.addTxnMarkersToSend(coordinatorEpoch, txnResult, txnMetadata1, txnMetadata1.prepareComplete(time.milliseconds()))
     channelManager.addTxnMarkersToSend(coordinatorEpoch, txnResult, txnMetadata2, txnMetadata2.prepareComplete(time.milliseconds()))
@@ -395,12 +398,12 @@ class TransactionMarkerChannelManagerTest {
       ArgumentMatchers.eq(partition1.topic),
       ArgumentMatchers.eq(partition1.partition),
       any())
-    ).thenReturn(Some(broker1))
+    ).thenReturn(Optional.of(broker1))
     when(metadataCache.getPartitionLeaderEndpoint(
       ArgumentMatchers.eq(partition2.topic),
       ArgumentMatchers.eq(partition2.partition),
       any())
-    ).thenReturn(Some(broker2))
+    ).thenReturn(Optional.of(broker2))
 
     channelManager.addTxnMarkersToSend(coordinatorEpoch, txnResult, txnMetadata1, txnMetadata1.prepareComplete(time.milliseconds()))
     channelManager.addTxnMarkersToSend(coordinatorEpoch, txnResult, txnMetadata2, txnMetadata2.prepareComplete(time.milliseconds()))
@@ -436,12 +439,12 @@ class TransactionMarkerChannelManagerTest {
       ArgumentMatchers.eq(partition1.topic),
       ArgumentMatchers.eq(partition1.partition),
       any())
-    ).thenReturn(Some(broker1))
+    ).thenReturn(Optional.of(broker1))
     when(metadataCache.getPartitionLeaderEndpoint(
       ArgumentMatchers.eq(partition2.topic),
       ArgumentMatchers.eq(partition2.partition),
       any())
-    ).thenReturn(Some(broker2))
+    ).thenReturn(Optional.of(broker2))
 
     val txnTransitionMetadata2 = txnMetadata2.prepareComplete(time.milliseconds())
 
@@ -478,7 +481,7 @@ class TransactionMarkerChannelManagerTest {
     assertEquals(0, channelManager.numTxnsWithPendingMarkers)
     assertEquals(0, channelManager.queueForBroker(broker1.id).get.totalNumMarkers)
     assertEquals(None, txnMetadata2.pendingState)
-    assertEquals(CompleteCommit, txnMetadata2.state)
+    assertEquals(TransactionState.COMPLETE_COMMIT, txnMetadata2.state)
   }
 
   @Test
@@ -489,12 +492,12 @@ class TransactionMarkerChannelManagerTest {
       ArgumentMatchers.eq(partition1.topic),
       ArgumentMatchers.eq(partition1.partition),
       any())
-    ).thenReturn(Some(broker1))
+    ).thenReturn(Optional.of(broker1))
     when(metadataCache.getPartitionLeaderEndpoint(
       ArgumentMatchers.eq(partition2.topic),
       ArgumentMatchers.eq(partition2.partition),
       any())
-    ).thenReturn(Some(broker2))
+    ).thenReturn(Optional.of(broker2))
 
     val txnTransitionMetadata2 = txnMetadata2.prepareComplete(time.milliseconds())
 
@@ -531,7 +534,7 @@ class TransactionMarkerChannelManagerTest {
     assertEquals(0, channelManager.numTxnsWithPendingMarkers)
     assertEquals(0, channelManager.queueForBroker(broker1.id).get.totalNumMarkers)
     assertEquals(None, txnMetadata2.pendingState)
-    assertEquals(PrepareCommit, txnMetadata2.state)
+    assertEquals(TransactionState.PREPARE_COMMIT, txnMetadata2.state)
   }
 
   @ParameterizedTest
@@ -546,12 +549,12 @@ class TransactionMarkerChannelManagerTest {
       ArgumentMatchers.eq(partition1.topic),
       ArgumentMatchers.eq(partition1.partition),
       any())
-    ).thenReturn(Some(broker1))
+    ).thenReturn(Optional.of(broker1))
     when(metadataCache.getPartitionLeaderEndpoint(
       ArgumentMatchers.eq(partition2.topic),
       ArgumentMatchers.eq(partition2.partition),
       any())
-    ).thenReturn(Some(broker2))
+    ).thenReturn(Optional.of(broker2))
 
     val txnTransitionMetadata2 = txnMetadata2.prepareComplete(time.milliseconds())
 
@@ -592,7 +595,7 @@ class TransactionMarkerChannelManagerTest {
     assertEquals(0, channelManager.numTxnsWithPendingMarkers)
     assertEquals(0, channelManager.queueForBroker(broker1.id).get.totalNumMarkers)
     assertEquals(None, txnMetadata2.pendingState)
-    assertEquals(CompleteCommit, txnMetadata2.state)
+    assertEquals(TransactionState.COMPLETE_COMMIT, txnMetadata2.state)
   }
 
   private def createPidErrorMap(errors: Errors): util.HashMap[java.lang.Long, util.Map[TopicPartition, Errors]] = {
