@@ -18,7 +18,7 @@
 package kafka.log
 
 import java.io.File
-import java.util.Properties
+import java.util.{Optional, Properties}
 import kafka.server.KafkaConfig
 import kafka.utils._
 import org.apache.kafka.common.TopicPartition
@@ -29,7 +29,7 @@ import org.apache.kafka.common.utils.Time
 import org.apache.kafka.server.config.ServerConfigs
 import org.apache.kafka.server.util.MockTime
 import org.apache.kafka.storage.internals.checkpoint.OffsetCheckpointFile
-import org.apache.kafka.storage.internals.log.{CleanerConfig, LogConfig}
+import org.apache.kafka.storage.internals.log.{CleanerConfig, LogCleanerManager, LogConfig, UnifiedLog}
 import org.junit.jupiter.api.Assertions._
 import org.junit.jupiter.api.extension.ExtensionContext
 import org.junit.jupiter.params.ParameterizedTest
@@ -69,7 +69,7 @@ class LogCleanerParameterizedIntegrationTest extends AbstractLogCleanerIntegrati
 
     checkLogAfterAppendingDups(log, startSize, appends)
 
-    val appendInfo = log.appendAsLeader(largeMessageSet, leaderEpoch = 0)
+    val appendInfo = log.appendAsLeader(largeMessageSet, 0)
     // move LSO forward to increase compaction bound
     log.updateHighWatermark(log.logEndOffset)
     val largeMessageOffset = appendInfo.firstOffset
@@ -85,8 +85,8 @@ class LogCleanerParameterizedIntegrationTest extends AbstractLogCleanerIntegrati
     // force a checkpoint
     // and make sure its gone from checkpoint file
     cleaner.logs.remove(topicPartitions(0))
-    cleaner.updateCheckpoints(logDir, partitionToRemove = Option(topicPartitions(0)))
-    val checkpoints = new OffsetCheckpointFile(new File(logDir, cleaner.cleanerManager.offsetCheckpointFile), null).read()
+    cleaner.updateCheckpoints(logDir, Optional.of(topicPartitions(0)))
+    val checkpoints = new OffsetCheckpointFile(new File(logDir, LogCleanerManager.OFFSET_CHECKPOINT_FILE), null).read()
     // we expect partition 0 to be gone
     assertFalse(checkpoints.containsKey(topicPartitions(0)))
   }
@@ -171,7 +171,7 @@ class LogCleanerParameterizedIntegrationTest extends AbstractLogCleanerIntegrati
     checkLogAfterAppendingDups(log, startSize, appends1)
 
     val dupsV0 = writeDups(numKeys = 40, numDups = 3, log = log, codec = compression, magicValue = RecordBatch.MAGIC_VALUE_V0)
-    val appendInfo = log.appendAsLeaderWithRecordVersion(largeMessageSet, leaderEpoch = 0, recordVersion = RecordVersion.V0)
+    val appendInfo = log.appendAsLeaderWithRecordVersion(largeMessageSet, 0, RecordVersion.V0)
     // move LSO forward to increase compaction bound
     log.updateHighWatermark(log.logEndOffset)
     val largeMessageOffset = appendInfo.firstOffset
@@ -242,7 +242,7 @@ class LogCleanerParameterizedIntegrationTest extends AbstractLogCleanerIntegrati
       if (compressionType == CompressionType.NONE)
         assertEquals(1, recordBatch.iterator().asScala.size)
       else
-        assertTrue(recordBatch.iterator().asScala.size >= 1)
+        assertTrue(recordBatch.iterator().asScala.nonEmpty)
 
       val firstRecordKey = TestUtils.readString(recordBatch.iterator().next().key())
       if (keysForV0RecordsWithNoV1V2Updates.contains(firstRecordKey))
@@ -280,7 +280,7 @@ class LogCleanerParameterizedIntegrationTest extends AbstractLogCleanerIntegrati
     // Verify no cleaning with LogCleanerIoBufferSizeProp=1
     val firstDirty = log.activeSegment.baseOffset
     val topicPartition = new TopicPartition("log", 0)
-    cleaner.awaitCleaned(topicPartition, firstDirty, maxWaitMs = 10)
+    cleaner.awaitCleaned(topicPartition, firstDirty, 10)
     assertTrue(cleaner.cleanerManager.allCleanerCheckpoints.isEmpty, "Should not have cleaned")
 
     def kafkaConfigWithCleanerConfig(cleanerConfig: CleanerConfig): KafkaConfig = {
@@ -317,8 +317,8 @@ class LogCleanerParameterizedIntegrationTest extends AbstractLogCleanerIntegrati
     // wait until cleaning up to base_offset, note that cleaning happens only when "log dirty ratio" is higher than
     // TopicConfig.MIN_CLEANABLE_DIRTY_RATIO_CONFIG
     val topicPartition = new TopicPartition(topic, partitionId)
-    cleaner.awaitCleaned(topicPartition, firstDirty)
-    val lastCleaned = cleaner.cleanerManager.allCleanerCheckpoints(topicPartition)
+    cleaner.awaitCleaned(topicPartition, firstDirty, 60000L)
+    val lastCleaned = cleaner.cleanerManager.allCleanerCheckpoints.get(topicPartition)
     assertTrue(lastCleaned >= firstDirty, s"log cleaner should have processed up to offset $firstDirty, but lastCleaned=$lastCleaned")
   }
 
@@ -353,7 +353,7 @@ class LogCleanerParameterizedIntegrationTest extends AbstractLogCleanerIntegrati
     }
 
     val appendInfo = log.appendAsLeaderWithRecordVersion(MemoryRecords.withRecords(magicValue, codec, records: _*),
-      leaderEpoch = 0, recordVersion = RecordVersion.lookup(magicValue))
+      0, RecordVersion.lookup(magicValue))
     // move LSO forward to increase compaction bound
     log.updateHighWatermark(log.logEndOffset)
     val offsets = appendInfo.firstOffset to appendInfo.lastOffset
